%%% SAMPLE US ENGLISH LEXICON
%%%
%%% Modifications: 
%%% 2014 Elly Matthias, Sandiway Fong, University of Arizona
%%%
%%% (c) 1994  Sandiway Fong, NEC Research Institute, Inc.
%%%

caseFoldInput.

default_features(n,[grid([],[]),case(_),theta(_)]).
default_features(v,[index(_)]).

block_default_features(nounFeatures,2).
block_default_features(verbToNounFeatures,2).

no superClass(_,_).
no blockContraction(_).

%%% EXPORT
%%%	default_features(C,Fs)		used in lexicon compilation
%%%	term(C)				terminals
%%%	lexicon(Word,C,Fs)		Word has category label C
%%%					and feature list Fs
%%%	probeLexicon(Word)		Word is in lexicon
%%%	vMorphToFs(Base,Form,Features)	TNS/AGR features
%%%	inf(Verb,Type)
%%%	relevant(C)			constraints imposed by markers
%%%					apply to C
%%% REFERENCES
%%%	(list processing)		utilities

term(n). term(a). term(v). term(p). term(c).
term(adv).  term(det). %term(conj).
term(neg). term(mrkr). term('$').

%%%	Most lexical entries are stored directly as
%%%
%%%		 lex(Word,Category,Features)
%%%
%%%	Non-base forms require inference:
%%%	1. plural nouns		all features except agr(_) inherited
%%%				from the sg. form
%%%	2. nominalized verbs	inherits verb features except morph(_,_)
%%%	3. non-base verb forms	all features except morph(_,_) inherited
%%%				from the base form

:- dynamic edrEng_lexicon/3.

lexicon(Word,C,Fs) :-
	nonvar(Word)
	-> (probeLexicon(Word)
	   -> builtin(Word,C,Fs)
	   ;  edrEng_lexicon(Word,C,Fs))
	;  builtin(Word,C,Fs).

% deterministic
probeLexicon(Word) :- lex(Word,_,_) -> true ; lex(Word,_,_,_), !.

builtin(Word,C,Fs) :- lex(Word,C,Fs).		% directly available
builtin(Form,v,Fs) :-				% non-base verb forms
	lex(Form,v,Base,F1),
	verbFeatures(Base,F2),
	append1(F1,F2,Fs).

% lexicon(Word,C,Fs) :- lex(Word,C,Fs).		% directly available
% lexicon(Form,v,Fs) :-				% non-base verb forms
%	lex(Form,v,Base,F1),
%	verbFeatures(Base,F2),
%	append1(F1,F2,Fs).

%%% NEGATION

lex(not,neg,[polarity(-)]).

%%% PREPOSITIONS

lex(about,p,[grid([],[theme]),predicate(theme),
	     adjR([goal(roleNotPresent(X,theme),X)])]).
lex(after,p,[grid([],[reducedProp]),selR([not(feature(inf([])))]),
	     predicate(manner)]). % use+ing
lex(because,p,[grid([],[reducedProp]),predicate(reason)]).
lex(before,p,[grid([],[reducedProp]),selR([not(feature(inf([])))]),
	      predicate(manner)]). % use+ing
lex(by,p,[grid([],[agent]),adjR([goal(unsaturatedExtRole(X,agent),X)]),
	  predicate(agent)]).
lex(down,p,[grid([],[location]),predicate(location)]).
lex(during,p,[grid([],[reducedProp]),selR([not(feature(inf([])))]),
	      predicate(manner)]). % use+ing
lex(in,p,[grid([],[location]),predicate(location)]).
lex(inside,p,[grid([],[location]),predicate(location)]).
lex(under,p,[grid([],[location]),predicate(location)]).

lex(on,p,[grid([],[location]),predicate(location)]).
lex(outside,p,[grid([],[location]),predicate(location)]).
lex(over,p,[grid([],[location]),predicate(location)]).
lex(to,p,[grid([],[destination]),predicate(destination),
	  adjR([goal(vpAllowExt(destination,X),X)])]).
lex(toward,p,[grid([],[destination]),predicate(destination),
	  adjR([goal(vpAllowExt(destination,X),X)])]).
lex(at,p,[grid([],[patient]),predicate(patient),  % .. at something/body
	  adjR([goal(vpAllowExt(patient,X),X)])]).
lex(while,p,[grid([],[reducedProp]),selR([not(feature(inf([])))]),
	      predicate(manner)]). % use+ing

lex(with,p,[grid([],[instrument]),predicate(instrument)]).

lex(with,p,[grid([],[goal]),predicate(goal), % with "some task"
	  adjR([goal(vpAllowExt(goal,X),X)])]).

lex(without,p,[grid([],[reducedProp]),selR([not(feature(inf([])))]),
	       predicate(manner)]). % use+ing

%% Adverbs

lex(how,adv,[adjoin(right),wh(+),predicate(manner)]).
lex(when,adv,[adjoin(right),wh(+),predicate(time)]).
lex(why,adv,[adjoin(right),wh(+),predicate(reason)]).
lex(completely,adv,[adjoin(_),predicate(manner)]).
lex(often,adv,[adjoin(left),predicate(manner)]).
lex(sincerely,adv,[adjoin(left),predicate(manner)]).
lex(here,adv,[adjoin(right),predicate(location)]).
lex(late,adv,[adjoin(right),predicate(time)]).
lex(now,adv,[adjoin(right),predicate(time)]).
lex(yesterday,adv,[adjoin(right),predicate(time)]).
lex(hard,adv,[degree,adjR([feature(allow(adv,degree))])]). % ... special case
lex(well,adv,[adjoin(right),predicate(manner)]).
lex(badly,adv,[adjoin(right),predicate(manner)]).
lex(quickly,adv,[adjoin(right),predicate(manner)]).
lex(slowly,adv,[adjoin(right),predicate(manner)]).
lex(quietly,adv,[adjoin(right),predicate(manner)]).
lex(loudly,adv,[adjoin(right),predicate(manner)]).
lex(softly,adv,[adjoin(right),predicate(manner)]).
lex(early,adv,[adjoin(right),predicate(time)]).
lex(professionally,adv,[adjoin(right),predicate(manner)]).
lex(poorly,adv,[adjoin(right),predicate(manner)]).
lex(satisfactorily,adv,[adjoin(right),predicate(manner)]).
lex(sadly,adv,[adjoin(left),predicate(manner)]).
lex(happily,adv,[adjoin(left),predicate(manner)]).
lex(fortunately,adv,[adjoin(right),predicate(manner)]).
lex(unfortunately,adv,[adjoin(right),predicate(manner)]).
lex(down,adv,[adjoin(right),predicate(manner)]).
lex(up,adv,[adjoin(right),predicate(manner)]).
lex(always,adv,[adjoin(left),predicate(manner)]).
lex(sometimes,adv,[adjoin(left),predicate(manner)]).
lex(never,adv,[adjoin(left),predicate(manner)]).

%% Degree Adverbs (modify adjectives)

% permit the resulting AP to take an optional clausal adjunct
lex(too,adv,[degree,adjR([addFeatures([allowExt(reason),adjR([goal(nonfiniteClause(X),X)])])])]).
lex(very,adv,[degree,adjR([addFeatures([allowExt(reason),adjR([goal(nonfiniteClause(X),X)])])])]).
lex(really,adv,[degree,adjR([addFeatures([allowExt(reason),adjR([goal(nonfiniteClause(X),X)])])])]).
lex(hardly,adv,[degree,adjR([addFeatures([allowExt(reason),adjR([goal(nonfiniteClause(X),X)])])])]).
lex(barely,adv,[degree,adjR([addFeatures([allowExt(reason),adjR([goal(nonfiniteClause(X),X)])])])]).
lex(super,adv,[degree,adjR([addFeatures([allowExt(reason),adjR([goal(nonfiniteClause(X),X)])])])]).
lex(somewhat,adv,[degree,adjR([addFeatures([allowExt(reason),adjR([goal(nonfiniteClause(X),X)])])])]).


%% Determiners
%%	Combine only with nouns that have the count(+/-/_) feature (common nouns)
%%	Six classes of determiners:
%%	Class Examples                     Features
%%	1     the,my,our,whose,which,what  count(_) agr([3,[],[]])
%%	2     some,any,enough              count(_) agr([3,[pl,m],[]])
%%	3     this,that                    count(_) agr([3,[sg,m],[]])
%%	4     few,these,those              count(+) agr([3,pl,[]])
%%	5     a,every,each,either,neither  count(+) agr(([3,sg,[]])
%%	6     much                         count(-) agr(([3,m,[]])
%%
%%	op(+) elements that are moved by QR and
%%	form operator-variable structures

lex(a,det,[count(+),agr([3,sg,[]]),vow(-),def(-)]).
lex(an,det,[count(+),agr([3,sg,[]]),vow(+),def(-)]).
lex(a_certain,det,[count(+),agr([3,sg,[]])]).
lex(all,det,[count(+),agr([3,pl,[]])]).
lex(any,det,[count(_),agr([3,[pl,m],[]])]).
lex(each,det,[count(+),agr([3,sg,[]]),op(+)]).
lex(either,det,[count(+),agr([3,sg,[]])]).
lex(enough,det,[count(_),agr([3,[pl,m],[]]),op(+)]).
lex(every,det,[count(+),agr([3,sg,[]]),op(+)]).
lex(few,det,[count(+),agr([3,pl,[]]),op(+)]).
lex(many,det,[count(+),agr([3,pl,[]]),op(+)]).
lex(much,det,[count(-),agr([3,m,[]]),op(+)]).
% lex(my,det,[count(_),agr([3,[],[]])]).
% lex(our,det,[count(_),agr([3,[],[]])]).
lex(neither,det,[count(+),agr([3,sg,[]])]).
lex(several,det,[count(_),agr([3,[],[]]),op(+)]).
lex(some,det,[count(_),agr([3,[],[]]),op(+)]).
lex(that,det,[count(_),agr([3,[sg,m],[]])]).
lex(the,det,[count(_),agr([3,[],[]])]).
lex(these,det,[count(+),agr([3,pl,[]])]).
lex(this,det,[count(_),agr([3,[sg,m],[]])]).
lex(those,det,[count(+),agr([3,pl,[]])]).
% lex(what,det,[count(_),agr([3,[],[]]),wh(+)]).
lex(which,det,[count(_),agr([3,[],[]]),wh(+)]).
lex(whose,det,[count(_),agr([3,[],[]]),wh(+)]).

%% Nouns
%%	Obligatory features
%%	1. Anaphoric: a(+/-), Pronominal: p(+/-) for Binding Theory
%%	2. Agreement: agr([Per,Num,Gen])
%%	3. O-grid: grid(Ext,Int)
%%	Optional features
%%	1. Morphologically realized Case: morphC(C)
%%	2. Common nouns: count(+/-/_) (not present for proper nouns)
%%	3. Quantifiers: op(+/-)
%%	4. Wh-nouns: wh(+)

% Numbers and Ordinals

lex(one,n,[morphC(gen),count(_),agr([3,sg,[]]),nonarg(+)]).
lex(two,n,[morphC(gen),count(_),agr([3,sg,[]]),nonarg(+)]).
lex(three,n,[morphC(gen),count(_),agr([3,pl,[]]),nonarg(+)]).
lex(four,n,[morphC(gen),count(_),agr([3,pl,[]]),nonarg(+)]).
lex(five,n,[morphC(gen),count(_),agr([3,pl,[]]),nonarg(+)]).
lex(six,n,[morphC(gen),count(_),agr([3,pl,[]]),nonarg(+)]).
lex(seven,n,[morphC(gen),count(_),agr([3,pl,[]]),nonarg(+)]).
lex(eight,n,[morphC(gen),count(_),agr([3,pl,[]]),nonarg(+)]).
lex(nine,n,[morphC(gen),count(_),agr([3,pl,[]]),nonarg(+)]).
lex(ten,n,[morphC(gen),count(_),agr([3,pl,[]]),nonarg(+)]).


lex(first,n,[morphC(gen),count(+),agr([3,sg,[]]),nonarg(+)]).
lex(second,n,[morphC(gen),count(+),agr([3,sg,[]]),nonarg(+)]).
lex(third,n,[morphC(gen),count(+),agr([3,sg,[]]),nonarg(+)]).
lex(fourth,n,[morphC(gen),count(+),agr([3,sg,[]]),nonarg(+)]).
lex(fifth,n,[morphC(gen),count(+),agr([3,sg,[]]),nonarg(+)]).
lex(sixth,n,[morphC(gen),count(+),agr([3,sg,[]]),nonarg(+)]).
lex(seventh,n,[morphC(gen),count(+),agr([3,sg,[]]),nonarg(+)]).
lex(eighth,n,[morphC(gen),count(+),agr([3,sg,[]]),nonarg(+)]).
lex(ninth,n,[morphC(gen),count(+),agr([3,sg,[]]),nonarg(+)]).
lex(tenth,n,[morphC(gen),count(+),agr([3,sg,[]]),nonarg(+)]).

% Pleonastic elements

lex(there,n,[theta(X),agr([3,[],[]]),nonarg(+),linkTo(np)]) :-
	optional(zero,X),
	notAssigned(X).

% default is non-argument unless the theta slot is instantiated, in which
% case, the argument status is choosen using the predicate chooseIt/3

lex(it,n,[agr([3,sg,n]),goal(theta(R),lambda(X,chooseIt(R,V,X))),
	  oneof(_,[[noCoindex,nonarg(V),linkTo(c2)],[a(-),p(+)]])]).

% not sure?
lex(now,n,[agr([3,[],[]])]).

% Proper nouns
lex(bill,n,[a(-),p(-),agr([3,sg,m])]).
lex(john,n,[a(-),p(-),agr([3,sg,m])]).
lex(mary,n,[a(-),p(-),agr([3,sg,f])]).
lex(peter,n,[a(-),p(-),agr([3,sg,m])]).
lex(sam,n,[a(-),p(-),agr([3,sg,[m,f]])]).
lex(sue,n,[a(-),p(-),agr([3,sg,f])]).
lex(susan,n,[a(-),p(-),agr([3,sg,f])]).

lex(rome,n,[a(-),p(-),agr([3,sg,n])]).
lex(france,n,[a(-),p(-),agr([3,sg,n])]).
lex(tucson,n,[a(-),p(-),agr([3,sg,n])]).
lex(phoenix,n,[a(-),p(-),agr([3,sg,n])]).
lex(arizona,n,[a(-),p(-),agr([3,sg,n])]).
lex(america,n,[a(-),p(-),agr([3,sg,n])]).
lex(england,n,[a(-),p(-),agr([3,sg,n])]).
lex(china,n,[a(-),p(-),agr([3,sg,n])]).
lex(mexico,n,[a(-),p(-),agr([3,sg,n])]).
lex(russia,n,[a(-),p(-),agr([3,sg,n])]).


% Anaphors and pronominals
lex(each_other,n,[a(+),p(-),agr([3,pl,[m,f]])]).

lex(he,n,[morphC(nom),a(-),p(+),agr([3,sg,m])]).
lex(him,n,[morphC(acc),a(-),p(+),agr([3,sg,m])]).
lex(himself,n,[a(+),p(-),agr([3,sg,m])]).

% 'their', 'his' ambiguous wrt Binding features
lex(his,n,[morphC(gen),agr([3,sg,m]),
	   goal(a(A),invPlusMinus(A,P)),p(P)]).
lex(its,n,[morphC(gen),agr([3,sg,n]),
	   goal(a(A),invPlusMinus(A,P)),p(P)]).
lex(their,n,[morphC(gen),agr([3,pl,[m,f]]),
	   goal(a(A),invPlusMinus(A,P)),p(P)]).

lex(them,n,[morphC(acc),a(-),p(+),agr([3,pl,[m,f]])]).

lex(themselves,n,[a(+),p(-),agr([3,pl,[m,f]]),
		  oneof(_,[[morphC(acc)],[morphC(gen)]])]).

lex(they,n,[morphC(nom),a(-),p(+),agr([3,pl,[m,f]])]).

lex(she,n,[morphC(nom),a(-),p(+),agr([3,sg,f])]).
lex(her,n,[morphC(acc),a(-),p(+),agr([3,sg,f])]).
lex(her,n,[morphC(gen),agr([3,sg,f]),
	   goal(a(A),invPlusMinus(A,P)),p(P)]).
lex(herself,n,[a(+),p(-),agr([3,sg,f])]).

lex(i,n,[morphC(nom),a(-),p(+),agr([1,sg,[m,f]])]).
lex(me,n,[morphC(acc),a(-),p(+),agr([1,sg,[m,f]])]).
% lex(my,n,[morphC(gen),a(-),p(+),agr([1,sg,[m,f]])]).
lex(my,n,[morphC(gen),
	  goal(a(A),invPlusMinus(A,P)),p(P),
	  agr([1,sg,[m,f]])]).
lex(myself,n,[a(+),p(-),agr([1,sg,[m,f]])]).

lex(you,n,[a(-),p(+),agr([2,[],[m,f]])]).
lex(your,n,[morphC(gen),
	  goal(a(A),invPlusMinus(A,P)),p(P),
	  agr([2,[sg,pl],[m,f]])]).

lex(we,n,[morphC(nom),a(-),p(+),agr([1,pl,[m,f]])]).
lex(us,n,[morphC(acc),a(-),p(+),agr([1,pl,[m,f]])]).
lex(our,n,[morphC(gen),
	  goal(a(A),invPlusMinus(A,P)),p(P),
	  agr([1,pl,[m,f]])]).

lex(itself,n,[a(+),p(-),agr([3,sg,n])]).

% Quantifier nouns
lex(everyone,n,[a(-),p(-),agr([3,sg,[m,f]]),op(+)]).
lex(nobody,n,[a(-),p(-),agr([3,sg,[m,f]]),op(+)]).
lex(somebody,n,[a(-),p(-),agr([3,sg,[m,f]]),op(+)]).
lex(someone,n,[a(-),p(-),agr([3,sg,[m,f]]),op(+)]).

% Wh-nouns
lex(who,n,[a(-),p(-),agr([3,sg,[m,f]]),wh(+)]).
lex(whom,n,[morphC(acc),a(-),p(-),agr([3,sg,[m,f]]),wh(+)]).
lex(what,n,[a(-),p(-),agr([3,[],n]),wh(+)]).
lex(which,n,[a(-),p(-),agr([3,[],n]),wh(+)]).
lex(why,n,[a(-),p(-),agr([3,[],n]),wh(+)]).

% Common nouns
lex(actress,n,[a(-),p(-),count(+),agr([3,sg,f]),vow]).
lex(actor,n,[a(-),p(-),count(+),agr([3,sg,m]),vow]).
lex(age,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(air,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(anger,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(animal,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(answer,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(apple,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(area,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(arm,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(art,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(article,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(award,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(baby,n,[a(-),p(-),count(+),agr([3,sg,[m,f]])]).
lex(back,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(ball,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(band,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(bank,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(bar,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(base,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(bastard,n,[a(-),p(-),count(+),agr([3,sg,[m,f]]),epithet]).
lex(bat,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(bear,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(beauty,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(bell,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(bird,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(bit,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(block,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(blood,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(blow,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(board,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(boat,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(body,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(bone,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(bottom,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(box,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(boy,n,[a(-),p(-),count(+),agr([3,sg,m])]).
lex(break,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(bread,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(branch,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(building,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(bus,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(cake,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(call,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(camp,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(capital,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(captain,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(car,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(card,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(care,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(case,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(cat,n,[a(-),p(-),count(+),agr([3,sg,[m,f]])]).
lex(cause,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(cell,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(cent,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(century,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(chair,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(chance,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(change,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(character,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(chick,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(cheese,n,[a(-),p(-),count(+),agr([3,[],n])]).
lex(chicken,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(chief,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(child,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(chord,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(class,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(cleaner,n,[a(-),p(-),count(+),agr([3,sg,[m,f]])]).
lex(city,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(climb,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(clock,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(cloud,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(coat,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(cold,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(color,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(column,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(company,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(computer,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(condition,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(consonant,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(continent,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(copy,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(corn,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(cost,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(cotton,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(country,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(course,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(cover,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(cow,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(crop,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(cross,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(crowd,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(cry,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(current,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(cut,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(dance,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(danger,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(day,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(dead,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(deal,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(death,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(decimal,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(degree,n,[a(-),p(-),count(+),agr([3,sg,n])]).
% lex(complaint,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(demonstration,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(design,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(dictionary,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(division,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(doctor,n,[a(-),p(-),agr([3,sg,[m,f]]),count(_)]).
lex(dog,n,[a(-),p(-),count(+),agr([3,sg,[m,f]])]).
lex(dollar,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(door,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(double,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(draw,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(dream,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(dress,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(drink,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(drive,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(drop,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(duck,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(ear,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(earth,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(ease,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(east,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(edge,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(effect,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(egg,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(elbow,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(element,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(end,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(enemy,n,[a(-),p(-),count(+),agr([3,sg,[m,f]])]).
lex(energy,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(engine,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(error,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(event,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(example,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(exchange,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(existence,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(expansion,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(eye,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(cloud,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(explosion,n,[a(-),p(-),count(+),agr([3,sg,n]),vow]).
lex(face,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(fact,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(fairy,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(fall,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(family,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(fang,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(farm,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(farmer,n,[a(-),p(-),count(+),agr([3,sg,[m,f]])]).
lex(faucet,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(fear,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(feast,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(feather,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(feeling,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(fiction,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(field,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(fish,n,[a(-),p(-),count(+),agr([3,[sg,pl],n])]).
lex(flag,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(flame,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(flavor,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(flesh,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(flight,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(finger,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(fire,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(flock,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(floor,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(flower,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(fog,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(fold,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(foot,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(force,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(fork,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(form,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(fowl,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(frame,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(friction,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(friend,n,[a(-),p(-),count(+),agr([3,sg,[m,f]])]).
lex(frog,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(front,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(fruit,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(fuel,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(furniture,n,[a(-),p(-),count(+),agr([3,sg,n])]).
% lex(frown,n,[a(-),p(-),count(+),agr([3,sg,n])]).
%
lex(game,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(garden,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(gate,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(ghost,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(giant,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(giraffe,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(girl,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(glass,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(glove,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(glue,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(goad,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(gold,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(goldfish,n,[a(-),p(-),count(+),agr([3,[sg,pl],n])]).
lex(goose,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(government,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(governor,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(grade,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(grain,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(grape,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(grass,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(grip,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(ground,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(group,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(growth,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(guide,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(guitar,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(gun,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(hand,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(haircut,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(hall,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(hammer,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(hand,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(harbor,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(harmony,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(hat,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(hate,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(head,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(health,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(hearing,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(heart,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(heat,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(help,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(hen,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(history,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(hobby,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(hole,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(holiday,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(home,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(honey,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(hook,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(hope,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(horn,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(horse,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(hose,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(hospital,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(hour,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(house,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(humor,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(hydrant,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(hold,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(homework,n,[a(-),p(-),count(-),agr([3,sg,n])]).
lex(ice_cream,n,[a(-),p(-),count(_),agr([3,[sg,m],n]),vow]).
lex(ice,n,[a(-),p(-),count(-),agr([3,[sg,pl],n])]).
lex(icicle,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(idea,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(impulse,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(income,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(increase,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(industry,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(ink,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(insect,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(instrument,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(insurance,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(interest,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(invention,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(iron,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(island,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(jacket,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(jail,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(jam,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(jar,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(jelly,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(jellyfish,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(jewel,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(joke,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(journey,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(judge,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(juice,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(jump,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(kettle,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(key,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(kick,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(kiss,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(kite,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(kitten,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(knee,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(knife,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(knot,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(knowledge,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(labor,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(lace,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(ladybug,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(lake,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(lamp,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(land,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(laugh,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(language,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(lawyer,n,[a(-),p(-),count(+),agr([3,sg,[m,f]])]).
lex(lead,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(leaf,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(leather,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(leg,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(letter,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(lettuce,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(level,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(library,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(lift,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(light,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(limit,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(line,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(liar,n,[a(-),p(-),count(+),agr([3,sg,[m,f]])]).
lex(lip,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(liquid,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(lizard,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(loaf,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(lock,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(locket,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(look,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(loss,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(love,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(lumber,n,[a(-),p(-),count(-),agr([3,[sg,pl],n])]).
lex(machine,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(magic,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(maid,n,[a(-),p(-),count(+),agr([3,sg,[m,f]])]).
lex(mailbox,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(man,n,[a(-),p(-),count(+),agr([3,sg,m])]).
lex(manager,n,[a(-),p(-),count(+),agr([3,sg,[m,f]])]).
lex(map,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(marble,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(mark,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(market,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(mass,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(match,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(meal,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(measure,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(meat,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(meeting,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(memory,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(metal,n,[a(-),p(-),count(-),agr([3,sg,n])]).
lex(middle,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(milk,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(mind,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(minister,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(mint,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(minute,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(mist,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(mitten,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(month,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(money,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(medal,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(mirror,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(moon,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(motion,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(muscle,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(music,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(nail,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(nation,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(neck,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(need,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(needle,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(nerve,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(nest,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(net,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(news,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(night,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(noise,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(north,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(nose,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(note,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(notebook,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(number,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(nut,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(oatmeal,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(observation,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(ocean,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(offer,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(office,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(officer,n,[a(-),p(-),count(+),agr([3,sg,[m,f]])]).
lex(oil,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(operation,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(opinion,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(orange,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(order,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(organization,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(ornament,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(oven,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(owl,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(owner,n,[a(-),p(-),count(+),agr([3,sg,[m,f]])]).
lex(page,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(pail,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(pain,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(paint,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(pan,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(pancake,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(pant,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(paper,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(parcel,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(part,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(partner,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(party,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(passenger,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(paste,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(patch,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(payment,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(peace,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(pear,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(pen,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(pencil,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(person,n,[a(-),p(-),count(+),agr([3,sg,[m,f]])]).
lex(pet,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(pickle,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(picture,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(pie,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(pin,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(pipe,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(pizza,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(place,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(plane,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(plan,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(plant,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(plastic,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(plate,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(play,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(playground,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(pleasure,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(plot,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(plough,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(pocket,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(point,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(poison,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(polish,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(pollution,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(popcorn,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(porter,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(position,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(pot,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(potato,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(powder,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(power,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(price,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(print,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(prism,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(prize,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(process,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(produce,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(profit,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(property,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(prose,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(protest,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(pump,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(punishment,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(purpose,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(push,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(police,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(policeman,n,[a(-),p(-),count(+),agr([3,sg,m])]).
lex(problem,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(quarter,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(quartz,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(queen,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(question,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(quicksand,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(quiet,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(quill,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(quilt,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(quiver,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(rabbit,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(rail,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(railway,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(railroad_station,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(race,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(rake,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(range,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(rat,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(rate,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(ray,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(reaction,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(reading,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(reason,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(receipt,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(recess,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(record,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(regret,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(relation,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(religion,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(report,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(representative,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(request,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(respect,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(rest,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(reward,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(rhythm,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(rice,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(riddle,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(rifle,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(ring,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(river,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(road,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(robin,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(rock,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(rod,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(roof,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(room,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(root,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(rose,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(route,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(rub,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(rule,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(run,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(sack,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(sail,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(salt,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(sand,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(sandwich,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(scale,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(scarecrow,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(scarf,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(scene,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(scent,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(school,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(science,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(scissors,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(screw,n,[a(-),p(-),count(+),agr([3,sg,n])]).
% lex(scowl,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(sea,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(seashore,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(seat,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(secretary,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(seed,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(selection,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(self,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(sense,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(servant,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(shade,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(shake,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(shame,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(shape,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(sheep,n,[a(-),p(-),count(+),agr([3,[sg,pl],n])]).
lex(sheet,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(shelf,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(ship,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(shirt,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(shock,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(shoe,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(shop,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(show,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(side,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(sidewalk,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(sign,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(silk,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(sink,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(skin,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(sky,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(slave,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(sleep,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(sleet,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(slope,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(smoke,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(snail,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(snake,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(sneeze,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(snow,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(soap,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(society,n,[a(-),p(-),count(+),agr([3,sg,n])]).
% lex(smile,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(sock,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(soda,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(sofa,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(song,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(sort,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(sound,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(soup,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(soldier,n,[a(-),p(-),agr([3,sg,[m,f]]),count(_)]).
lex(space,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(spade,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(spark,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(spider,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(sponge,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(spoon,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(spot,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(spring,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(spry,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(square,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(squirrel,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(stage,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(stain,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(stamp,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(star,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(statement,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(station,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(steam,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(steel,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(stem,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(step,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(stew,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(stick,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(stitch,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(stocking,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(stomach,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(stone,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(store,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(story,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(stranger,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(student,n,[a(-),p(-),agr([3,sg,[m,f]]),count(_)]).
lex(straw,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(stream,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(street,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(stretch,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(string,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(structure,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(substance,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(sugar,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(suggestion,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(suit,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(summer,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(sun,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(support,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(surprise,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(sweater,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(swing,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(system,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(symphony,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(syntactic_structures,n,[a(-),p(-),count(-),agr([3,sg,n])]).
lex(table,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(tail,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(talk,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(tank,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(taste,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(tax,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(teacher,n,[a(-),p(-),agr([3,sg,[m,f]]),count(_)]).
lex(team,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(telescope,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(temper,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(tendency,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(tent,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(territory,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(test,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(texture,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(theory,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(thing,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(thought,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(thread,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(thrill,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(throat,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(throne,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(thumb,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(thunder,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(ticket,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(tiger,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(time,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(this,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(title,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(toad,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(toe,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(tomato,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(tongue,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(tooth,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(town,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(toy,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(trail,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(train,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(tramp,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(transport,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(tray,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(tree,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(trick,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(trouble,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(truck,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(tub,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(turkey,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(turn,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(twig,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(twist,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(umbrella,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(underwear,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(unit,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(use,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(unicorn,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(university,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(vacation,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(value,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(van,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(vase,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(vegetable,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(veil,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(vein,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(verse,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(vessel,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(vest,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(view,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(visitor,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(voice,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(volcano,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(volleyball,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(voyage,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(walk,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(wall,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(war,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(wash,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(waste,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(watch,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(water,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(wave,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(wax,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(way,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(wealth,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(weather,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(week,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(weight,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(wheel,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(whip,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(whistle,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(wilderness,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(wind,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(window,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(wine,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(wing,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(winter,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(wire,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(wish,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(wood,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(wool,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(word,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(work,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(worm,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(wound,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(wrench,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(wrist,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(writer,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(writing,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(woman,n,[a(-),p(-),count(+),agr([3,sg,f])]).
lex(worker,n,[a(-),p(-),count(+),agr([3,sg,[m,f]])]).
lex(yak,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(yam,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(yard,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(yarn,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(yoke,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(year,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(zebra,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(zephyr,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(zinc,n,[a(-),p(-),count(-),agr([3,m,n])]).
lex(zipper,n,[a(-),p(-),count(+),agr([3,sg,n])]).
lex(zoo,n,[a(-),p(-),count(+),agr([3,sg,n])]).


% Nouns with O-grids
lex(aunt,n,[grid([possessor],[]),a(-),p(-),count(+),agr([3,sg,f])]).
lex(book,n,[grid([possessor],[]),a(-),p(-),count(+),agr([3,sg,n])]).
lex(brother,n,[grid([possessor],[]),a(-),p(-),count(+),agr([3,sg,m])]).
lex(father,n,[grid([possessor],[]),a(-),p(-),count(+),agr([3,sg,m])]).
lex(furniture,n,[grid([possessor],[]),a(-),p(-),count(-),agr([3,m,n])]).
lex(grandfather,n,[grid([possessor],[]),a(-),p(-),count(+),agr([3,sg,m])]).
lex(grandmother,n,[grid([possessor],[]),a(-),p(-),count(+),agr([3,sg,f])]).
lex(mind,n,[grid([possessor],[]),a(-),p(-),count(-),agr([3,m,n])]).
lex(mother,n,[grid([possessor],[]),a(-),p(-),count(+),agr([3,sg,f])]).
lex(owner,n,[grid([theme],[]),a(-),p(-),count(+),agr([3,sg,[]])]). % temp: its owner
lex(paycheck,n,[grid([possessor],[]),a(-),p(-),count(+),agr([3,sg,n])]).
lex(picture,n,[grid([possessor],[theme]),a(-),p(-),count(+),agr([3,sg,n])]).
lex(sister,n,[grid([possessor],[]),a(-),p(-),count(+),agr([3,sg,f])]).
lex(uncle,n,[grid([possessor],[]),a(-),p(-),count(+),agr([3,sg,m])]).


% Non-base noun forms

lex(actresses,n,[agr([3,pl,f])|F]) :- nounFeatures(actress,F).
lex(actors,n,[agr([3,pl,m])|F]) :- nounFeatures(actor,F).
lex(ages,n,[agr([3,pl,n])|F]) :- nounFeatures(age,F).
lex(airs,n,[agr([3,pl,n])|F]) :- nounFeatures(air,F).
lex(animals,n,[agr([3,pl,n])|F]) :- nounFeatures(animal,F).
lex(answers,n,[agr([3,pl,n])|F]) :- nounFeatures(answer,F).
lex(apples,n,[agr([3,pl,n])|F]) :- nounFeatures(apple,F).
lex(areas,n,[agr([3,pl,n])|F]) :- nounFeatures(area,F).
lex(arms,n,[agr([3,pl,n])|F]) :- nounFeatures(arm,F).
lex(arts,n,[agr([3,pl,n])|F]) :- nounFeatures(art,F).
lex(articles,n,[agr([3,pl,n])|F]) :- nounFeatures(article,F).
lex(awards,n,[agr([3,pl,n])|F]) :- nounFeatures(award,F).
lex(babies,n,[agr([3,pl,[m,f]])|F]) :- nounFeatures(baby,F).
lex(backs,n,[agr([3,pl,n])|F]) :- nounFeatures(back,F).
lex(balls,n,[agr([3,pl,n])|F]) :- nounFeatures(ball,F).
lex(bands,n,[agr([3,pl,n])|F]) :- nounFeatures(band,F).
lex(banks,n,[agr([3,pl,n])|F]) :- nounFeatures(bank,F).
lex(bars,n,[agr([3,pl,n])|F]) :- nounFeatures(bar,F).
lex(bases,n,[agr([3,pl,n])|F]) :- nounFeatures(base,F).
lex(bastards,n,[agr([3,pl,[m,f]])|F]) :- nounFeatures(bastard,F).
lex(bats,n,[agr([3,pl,n])|F]) :- nounFeatures(bat,F).
lex(bears,n,[agr([3,pl,n])|F]) :- nounFeatures(bear,F).
lex(beauties,n,[agr([3,pl,n])|F]) :- nounFeatures(beauty,F).
lex(bells,n,[agr([3,pl,n])|F]) :- nounFeatures(bell,F).
lex(beliefs,n,[agr([3,pl,n])|F]) :- nounFeatures(belief,F).
lex(birds,n,[agr([3,pl,n])|F]) :- nounFeatures(bird,F).
lex(bits,n,[agr([3,pl,n])|F]) :- nounFeatures(bit,F).
lex(blocks,n,[agr([3,pl,n])|F]) :- nounFeatures(block,F).
lex(blows,n,[agr([3,pl,n])|F]) :- nounFeatures(blow,F).
lex(boards,n,[agr([3,pl,n])|F]) :- nounFeatures(board,F).
lex(boats,n,[agr([3,pl,n])|F]) :- nounFeatures(boat,F).
lex(bodies,n,[agr([3,pl,n])|F]) :- nounFeatures(body,F).
lex(bones,n,[agr([3,pl,n])|F]) :- nounFeatures(bone,F).
lex(books,n,[agr([3,pl,n])|F]) :- nounFeatures(book,F).
lex(bottoms,n,[agr([3,pl,n])|F]) :- nounFeatures(bottom,F).
lex(boxes,n,[agr([3,pl,n])|F]) :- nounFeatures(box,F).
lex(boys,n,[agr([3,pl,m])|F]) :- nounFeatures(boy,F).
lex(breaks,n,[agr([3,pl,n])|F]) :- nounFeatures(break,F).
lex(breads,n,[agr([3,pl,n])|F]) :- nounFeatures(bread,F).
lex(branches,n,[agr([3,pl,n])|F]) :- nounFeatures(branch,F).
lex(buildings,n,[agr([3,pl,n])|F]) :- nounFeatures(building,F).
lex(buses,n,[agr([3,pl,n])|F]) :- nounFeatures(bus,F).
lex(cakes,n,[agr([3,pl,n])|F]) :- nounFeatures(cake,F).
lex(calls,n,[agr([3,pl,n])|F]) :- nounFeatures(call,F).
lex(camps,n,[agr([3,pl,n])|F]) :- nounFeatures(camp,F).
lex(capitals,n,[agr([3,pl,n])|F]) :- nounFeatures(capital,F).
lex(captains,n,[agr([3,pl,n])|F]) :- nounFeatures(captain,F).
lex(cars,n,[agr([3,pl,n])|F]) :- nounFeatures(car,F).
lex(cards,n,[agr([3,pl,n])|F]) :- nounFeatures(card,F).
lex(cares,n,[agr([3,pl,n])|F]) :- nounFeatures(care,F).
lex(cases,n,[agr([3,pl,n])|F]) :- nounFeatures(case,F).
lex(cats,n,[agr([3,pl,[m,f]])|F]) :- nounFeatures(cat,F).
lex(causes,n,[agr([3,pl,n])|F]) :- nounFeatures(cause,F).
lex(cells,n,[agr([3,pl,n])|F]) :- nounFeatures(cell,F).
lex(cents,n,[agr([3,pl,n])|F]) :- nounFeatures(cent,F).
lex(centuries,n,[agr([3,pl,n])|F]) :- nounFeatures(century,F).
lex(chairs,n,[agr([3,pl,n])|F]) :- nounFeatures(chair,F).
lex(chances,n,[agr([3,pl,n])|F]) :- nounFeatures(chance,F).
lex(changes,n,[agr([3,pl,n])|F]) :- nounFeatures(change,F).
lex(characters,n,[agr([3,pl,n])|F]) :- nounFeatures(character,F).
lex(chicks,n,[agr([3,pl,n])|F]) :- nounFeatures(chick,F).
lex(cheeses,n,[agr([3,pl,n])|F]) :- nounFeatures(cheese,F).
lex(chiefs,n,[agr([3,pl,n])|F]) :- nounFeatures(chief,F).
lex(children,n,[agr([3,pl,n])|F]) :- nounFeatures(child,F).
lex(chords,n,[agr([3,pl,n])|F]) :- nounFeatures(chord,F).
lex(cities,n,[agr([3,pl,n])|F]) :- nounFeatures(city,F).
lex(classes,n,[agr([3,pl,n])|F]) :- nounFeatures(class,F).
lex(climbs,n,[agr([3,pl,n])|F]) :- nounFeatures(climb,F).
lex(clocks,n,[agr([3,pl,n])|F]) :- nounFeatures(clock,F).
lex(clouds,n,[agr([3,pl,n])|F]) :- nounFeatures(cloud,F).
lex(cleaners,n,[agr([3,pl,[m,f]])|F]) :- nounFeatures(cleaner,F).
lex(coats,n,[agr([3,pl,n])|F]) :- nounFeatures(coat,F).
lex(colds,n,[agr([3,pl,n])|F]) :- nounFeatures(cold,F).
lex(colors,n,[agr([3,pl,n])|F]) :- nounFeatures(color,F).
lex(columns,n,[agr([3,pl,n])|F]) :- nounFeatures(column,F).
lex(companies,n,[agr([3,pl,n])|F]) :- nounFeatures(company,F).
lex(computers,n,[agr([3,pl,n])|F]) :- nounFeatures(computer,F).
lex(complaints,n,[agr([3,pl,n])|F]) :- nounFeatures(complaint,F).
lex(conditions,n,[agr([3,pl,n])|F]) :- nounFeatures(condition,F).
lex(consonants,n,[agr([3,pl,n])|F]) :- nounFeatures(consonant,F).
lex(continents,n,[agr([3,pl,n])|F]) :- nounFeatures(continent,F).
lex(copies,n,[agr([3,pl,n])|F]) :- nounFeatures(copy,F).
lex(costs,n,[agr([3,pl,n])|F]) :- nounFeatures(cost,F).
lex(countries,n,[agr([3,pl,n])|F]) :- nounFeatures(country,F).
lex(courses,n,[agr([3,pl,n])|F]) :- nounFeatures(course,F).
lex(covers,n,[agr([3,pl,n])|F]) :- nounFeatures(cover,F).
lex(cows,n,[agr([3,pl,n])|F]) :- nounFeatures(cow,F).
lex(crops,n,[agr([3,pl,n])|F]) :- nounFeatures(crop,F).
lex(crosses,n,[agr([3,pl,n])|F]) :- nounFeatures(cross,F).
lex(crowds,n,[agr([3,pl,n])|F]) :- nounFeatures(crowd,F).
lex(cries,n,[agr([3,pl,n])|F]) :- nounFeatures(cry,F).
lex(currents,n,[agr([3,pl,n])|F]) :- nounFeatures(current,F).
lex(cuts,n,[agr([3,pl,n])|F]) :- nounFeatures(cut,F).
lex(dances,n,[agr([3,pl,n])|F]) :- nounFeatures(dance,F).
lex(dangers,n,[agr([3,pl,n])|F]) :- nounFeatures(danger,F).
lex(days,n,[agr([3,pl,n])|F]) :- nounFeatures(day,F).
lex(deals,n,[agr([3,pl,n])|F]) :- nounFeatures(deal,F).
lex(deaths,n,[agr([3,pl,n])|F]) :- nounFeatures(death,F).
lex(decimals,n,[agr([3,pl,n])|F]) :- nounFeatures(decimal,F).
lex(degrees,n,[agr([3,pl,n])|F]) :- nounFeatures(degree,F).
lex(demonstrations,n,[agr([3,pl,n])|F]) :- nounFeatures(demonstration,F).
lex(departures,n,[agr([3,pl,n])|F]) :- nounFeatures(departure,F).
lex(designs,n,[agr([3,pl,n])|F]) :- nounFeatures(design,F).
lex(dictionaries,n,[agr([3,pl,n])|F]) :- nounFeatures(dictionary,F).
lex(divisions,n,[agr([3,pl,n])|F]) :- nounFeatures(division,F).
lex(doctors,n,[agr([3,pl,n])|F]) :- nounFeatures(doctor,F).
lex(dogs,n,[agr([3,pl,[m,f]])|F]) :- nounFeatures(dog,F).
lex(dollars,n,[agr([3,pl,n])|F]) :- nounFeatures(dollar,F).
lex(doors,n,[agr([3,pl,n])|F]) :- nounFeatures(door,F).
lex(draws,n,[agr([3,pl,n])|F]) :- nounFeatures(draw,F).
lex(dreams,n,[agr([3,pl,n])|F]) :- nounFeatures(dream,F).
lex(dresses,n,[agr([3,pl,n])|F]) :- nounFeatures(dress,F).
lex(drinks,n,[agr([3,pl,n])|F]) :- nounFeatures(drink,F).
lex(drives,n,[agr([3,pl,n])|F]) :- nounFeatures(drive,F).
lex(drops,n,[agr([3,pl,n])|F]) :- nounFeatures(drop,F).
lex(ducks,n,[agr([3,pl,n])|F]) :- nounFeatures(duck,F).
lex(ears,n,[agr([3,pl,n])|F]) :- nounFeatures(ear,F).
lex(earths,n,[agr([3,pl,n])|F]) :- nounFeatures(earth,F).
lex(edges,n,[agr([3,pl,n])|F]) :- nounFeatures(edge,F).
lex(effects,n,[agr([3,pl,n])|F]) :- nounFeatures(effect,F).
lex(eggs,n,[agr([3,pl,n])|F]) :- nounFeatures(egg,F).
lex(elbows,n,[agr([3,pl,n])|F]) :- nounFeatures(elbow,F).
lex(elements,n,[agr([3,pl,n])|F]) :- nounFeatures(element,F).
lex(ends,n,[agr([3,pl,n])|F]) :- nounFeatures(end,F).
lex(enemies,n,[agr([3,pl,[m,f]])|F]) :- nounFeatures(enemy,F).
lex(energies,n,[agr([3,pl,n])|F]) :- nounFeatures(energy,F).
lex(engines,n,[agr([3,pl,n])|F]) :- nounFeatures(engine,F).
lex(errors,n,[agr([3,pl,n])|F]) :- nounFeatures(error,F).
lex(events,n,[agr([3,pl,n])|F]) :- nounFeatures(event,F).
lex(examples,n,[agr([3,pl,n])|F]) :- nounFeatures(example,F).
lex(exchanges,n,[agr([3,pl,n])|F]) :- nounFeatures(exchange,F).
lex(existences,n,[agr([3,pl,n])|F]) :- nounFeatures(existence,F).
lex(expansions,n,[agr([3,pl,n])|F]) :- nounFeatures(expansion,F).
lex(experiences,n,[agr([3,pl,n])|F]) :- nounFeatures(experience,F).
lex(experts,n,[agr([3,pl,n])|F]) :- nounFeatures(expert,F).
lex(explosions,n,[agr([3,pl,n])|F]) :- nounFeatures(explosion,F).
lex(eyes,n,[agr([3,pl,n])|F]) :- nounFeatures(eye,F).
lex(faces,n,[agr([3,pl,n])|F]) :- nounFeatures(face,F).
lex(facts,n,[agr([3,pl,n])|F]) :- nounFeatures(fact,F).
lex(fairies,n,[agr([3,pl,n])|F]) :- nounFeatures(fairy,F).
lex(falls,n,[agr([3,pl,n])|F]) :- nounFeatures(fall,F).
lex(families,n,[agr([3,pl,n])|F]) :- nounFeatures(family,F).
lex(fangs,n,[agr([3,pl,n])|F]) :- nounFeatures(fang,F).
lex(farms,n,[agr([3,pl,n])|F]) :- nounFeatures(farm,F).
lex(farmers,n,[agr([3,pl,[m,f]])|F]) :- nounFeatures(farmer,F).
lex(faucets,n,[agr([3,pl,n])|F]) :- nounFeatures(faucet,F).
lex(fears,n,[agr([3,pl,n])|F]) :- nounFeatures(fear,F).
lex(feasts,n,[agr([3,pl,n])|F]) :- nounFeatures(feast,F).
lex(feathers,n,[agr([3,pl,n])|F]) :- nounFeatures(feather,F).
lex(feelings,n,[agr([3,pl,n])|F]) :- nounFeatures(feeling,F).
lex(feet,n,[agr([3,pl,n])|F]) :- nounFeatures(foot,F).
lex(fictions,n,[agr([3,pl,n])|F]) :- nounFeatures(fiction,F).
lex(fields,n,[agr([3,pl,n])|F]) :- nounFeatures(field,F).
lex(fingers,n,[agr([3,pl,n])|F]) :- nounFeatures(finger,F).
lex(fires,n,[agr([3,pl,n])|F]) :- nounFeatures(fire,F).
lex(flags,n,[agr([3,pl,n])|F]) :- nounFeatures(flag,F).
lex(flames,n,[agr([3,pl,n])|F]) :- nounFeatures(flame,F).
lex(flavors,n,[agr([3,pl,n])|F]) :- nounFeatures(flavor,F).
lex(flights,n,[agr([3,pl,n])|F]) :- nounFeatures(flight,F).
lex(flocks,n,[agr([3,pl,n])|F]) :- nounFeatures(flock,F).
lex(floors,n,[agr([3,pl,n])|F]) :- nounFeatures(floor,F).
lex(flowers,n,[agr([3,pl,n])|F]) :- nounFeatures(flower,F).
lex(fogs,n,[agr([3,pl,n])|F]) :- nounFeatures(fog,F).
lex(folds,n,[agr([3,pl,n])|F]) :- nounFeatures(fold,F).
lex(forces,n,[agr([3,pl,n])|F]) :- nounFeatures(force,F).
lex(forks,n,[agr([3,pl,n])|F]) :- nounFeatures(fork,F).
lex(forms,n,[agr([3,pl,n])|F]) :- nounFeatures(form,F).
lex(frames,n,[agr([3,pl,n])|F]) :- nounFeatures(frame,F).
lex(friends,n,[agr([3,pl,[m,f]])|F]) :- nounFeatures(friend,F).
lex(frogs,n,[agr([3,pl,n])|F]) :- nounFeatures(frog,F).
lex(frowns,n,[agr([3,pl,n])|F]) :- nounFeatures(frown,F).
lex(fronts,n,[agr([3,pl,n])|F]) :- nounFeatures(front,F).
lex(games,n,[agr([3,pl,n])|F]) :- nounFeatures(game,F).
lex(gardens,n,[agr([3,pl,n])|F]) :- nounFeatures(garden,F).
lex(gates,n,[agr([3,pl,n])|F]) :- nounFeatures(gate,F).
lex(ghosts,n,[agr([3,pl,n])|F]) :- nounFeatures(ghost,F).
lex(giants,n,[agr([3,pl,n])|F]) :- nounFeatures(giant,F).
lex(giraffes,n,[agr([3,pl,n])|F]) :- nounFeatures(giraffe,F).
lex(girls,n,[agr([3,pl,n])|F]) :- nounFeatures(girl,F).
lex(glasses,n,[agr([3,pl,n])|F]) :- nounFeatures(glass,F).
lex(gloves,n,[agr([3,pl,n])|F]) :- nounFeatures(glove,F).
lex(glues,n,[agr([3,pl,n])|F]) :- nounFeatures(glue,F).
lex(goats,n,[agr([3,pl,n])|F]) :- nounFeatures(goat,F).
lex(geese,n,[agr([3,pl,n])|F]) :- nounFeatures(goose,F).
lex(governments,n,[agr([3,pl,n])|F]) :- nounFeatures(government,F).
lex(governors,n,[agr([3,pl,n])|F]) :- nounFeatures(governor,F).
lex(grades,n,[agr([3,pl,n])|F]) :- nounFeatures(grade,F).
lex(grains,n,[agr([3,pl,n])|F]) :- nounFeatures(grain,F).
lex(grapes,n,[agr([3,pl,n])|F]) :- nounFeatures(grape,F).
lex(grasses,n,[agr([3,pl,n])|F]) :- nounFeatures(grass,F).
lex(grips,n,[agr([3,pl,n])|F]) :- nounFeatures(grip,F).
lex(grounds,n,[agr([3,pl,n])|F]) :- nounFeatures(ground,F).
lex(groups,n,[agr([3,pl,n])|F]) :- nounFeatures(group,F).
lex(growths,n,[agr([3,pl,n])|F]) :- nounFeatures(growth,F).
lex(guides,n,[agr([3,pl,n])|F]) :- nounFeatures(guide,F).
lex(guitars,n,[agr([3,pl,n])|F]) :- nounFeatures(guitar,F).
lex(guns,n,[agr([3,pl,n])|F]) :- nounFeatures(gun,F).
lex(haircuts,n,[agr([3,pl,n])|F]) :- nounFeatures(haircut,F).
lex(halls,n,[agr([3,pl,n])|F]) :- nounFeatures(hall,F).
lex(hammers,n,[agr([3,pl,n])|F]) :- nounFeatures(hammer,F).
lex(hands,n,[agr([3,pl,n])|F]) :- nounFeatures(hand,F).
lex(harbors,n,[agr([3,pl,n])|F]) :- nounFeatures(harbor,F).
lex(harmonies,n,[agr([3,pl,n])|F]) :- nounFeatures(harmony,F).
lex(hats,n,[agr([3,pl,n])|F]) :- nounFeatures(hat,F).
lex(heads,n,[agr([3,pl,n])|F]) :- nounFeatures(head,F).
lex(hearings,n,[agr([3,pl,n])|F]) :- nounFeatures(hearing,F).
lex(hearts,n,[agr([3,pl,n])|F]) :- nounFeatures(heart,F).
lex(hens,n,[agr([3,pl,n])|F]) :- nounFeatures(hen,F).
lex(hills,n,[agr([3,pl,n])|F]) :- nounFeatures(hill,F).
lex(histories,n,[agr([3,pl,n])|F]) :- nounFeatures(history,F).
lex(hobbies,n,[agr([3,pl,n])|F]) :- nounFeatures(hobby,F).
lex(holes,n,[agr([3,pl,n])|F]) :- nounFeatures(hole,F).
lex(holidays,n,[agr([3,pl,n])|F]) :- nounFeatures(holiday,F).
lex(homes,n,[agr([3,pl,n])|F]) :- nounFeatures(home,F).
lex(hooks,n,[agr([3,pl,n])|F]) :- nounFeatures(hook,F).
lex(horns,n,[agr([3,pl,n])|F]) :- nounFeatures(horn,F).
lex(horses,n,[agr([3,pl,n])|F]) :- nounFeatures(horse,F).
lex(hoses,n,[agr([3,pl,n])|F]) :- nounFeatures(hose,F).
lex(hospitals,n,[agr([3,pl,n])|F]) :- nounFeatures(hospital,F).
lex(hours,n,[agr([3,pl,n])|F]) :- nounFeatures(hour,F).
lex(houses,n,[agr([3,pl,n])|F]) :- nounFeatures(house,F).
lex(hydrants,n,[agr([3,pl,n])|F]) :- nounFeatures(hydrant,F).
lex(holes,n,[agr([3,pl,n])|F]) :- nounFeatures(hole,F).
lex(ice_creams,n,[agr([3,pl,n])|F]) :-
	nounFeatures(ice_cream,F),
	memberchk(count(+),F).
lex(icicles,n,[agr([3,pl,n])|F]) :- nounFeatures(icicle,F).
lex(ideas,n,[agr([3,pl,n])|F]) :- nounFeatures(idea,F).
lex(impulses,n,[agr([3,pl,n])|F]) :- nounFeatures(impulse,F).
lex(incomes,n,[agr([3,pl,n])|F]) :- nounFeatures(income,F).
lex(increases,n,[agr([3,pl,n])|F]) :- nounFeatures(increase,F).
lex(industries,n,[agr([3,pl,n])|F]) :- nounFeatures(industry,F).
lex(insects,n,[agr([3,pl,n])|F]) :- nounFeatures(insect,F).
lex(instruments,n,[agr([3,pl,n])|F]) :- nounFeatures(instrument,F).
lex(interests,n,[agr([3,pl,n])|F]) :- nounFeatures(interest,F).
lex(inventions,n,[agr([3,pl,n])|F]) :- nounFeatures(invention,F).
lex(irons,n,[agr([3,pl,n])|F]) :- nounFeatures(iron,F).
lex(islands,n,[agr([3,pl,n])|F]) :- nounFeatures(island,F).
lex(jackets,n,[agr([3,pl,n])|F]) :- nounFeatures(jacket,F).
lex(jails,n,[agr([3,pl,n])|F]) :- nounFeatures(jail,F).
lex(jams,n,[agr([3,pl,n])|F]) :- nounFeatures(jam,F).
lex(jars,n,[agr([3,pl,n])|F]) :- nounFeatures(jar,F).
lex(jewels,n,[agr([3,pl,n])|F]) :- nounFeatures(jewel,F).
lex(jokes,n,[agr([3,pl,n])|F]) :- nounFeatures(joke,F).
lex(journeys,n,[agr([3,pl,n])|F]) :- nounFeatures(journey,F).
lex(judges,n,[agr([3,pl,n])|F]) :- nounFeatures(judge,F).
lex(juices,n,[agr([3,pl,n])|F]) :- nounFeatures(juice,F).
lex(jumps,n,[agr([3,pl,n])|F]) :- nounFeatures(jump,F).
lex(kettles,n,[agr([3,pl,n])|F]) :- nounFeatures(kettle,F).
lex(keys,n,[agr([3,pl,n])|F]) :- nounFeatures(key,F).
lex(kicks,n,[agr([3,pl,n])|F]) :- nounFeatures(kick,F).
lex(kisses,n,[agr([3,pl,n])|F]) :- nounFeatures(kiss,F).
lex(kites,n,[agr([3,pl,n])|F]) :- nounFeatures(kite,F).
lex(kittens,n,[agr([3,pl,n])|F]) :- nounFeatures(kitten,F).
lex(knees,n,[agr([3,pl,n])|F]) :- nounFeatures(knee,F).
lex(knives,n,[agr([3,pl,n])|F]) :- nounFeatures(knife,F).
lex(knots,n,[agr([3,pl,n])|F]) :- nounFeatures(knot,F).
lex(ladybugs,n,[agr([3,pl,n])|F]) :- nounFeatures(ladybug,F).
lex(lakes,n,[agr([3,pl,n])|F]) :- nounFeatures(lake,F).
lex(lamps,n,[agr([3,pl,n])|F]) :- nounFeatures(lamp,F).
lex(languages,n,[agr([3,pl,n])|F]) :- nounFeatures(language,F).
lex(lawyers,n,[agr([3,pl,[m,f]])|F]) :- nounFeatures(lawyer,F).
lex(laughs,n,[agr([3,pl,n])|F]) :- nounFeatures(laugh,F).
lex(leads,n,[agr([3,pl,n])|F]) :- nounFeatures(lead,F).
lex(leaves,n,[agr([3,pl,n])|F]) :- nounFeatures(leaf,F).
lex(legs,n,[agr([3,pl,n])|F]) :- nounFeatures(leg,F).
lex(letters,n,[agr([3,pl,n])|F]):- nounFeatures(letter,F).
lex(levels,n,[agr([3,pl,n])|F]) :- nounFeatures(level,F).
lex(liars,n,[agr([3,pl,[m,f]])|F]) :- nounFeatures(liar,F).
lex(lifts,n,[agr([3,pl,n])|F]) :- nounFeatures(lift,F).
lex(lights,n,[agr([3,pl,n])|F]) :- nounFeatures(light,F).
lex(limits,n,[agr([3,pl,n])|F]) :- nounFeatures(limit,F).
lex(lines,n,[agr([3,pl,n])|F]) :- nounFeatures(line,F).
lex(lips,n,[agr([3,pl,n])|F]) :- nounFeatures(lip,F).
lex(liquids,n,[agr([3,pl,n])|F]) :- nounFeatures(liquid,F).
lex(lists,n,[agr([3,pl,n])|F]) :- nounFeatures(list,F).
lex(lizards,n,[agr([3,pl,n])|F]) :- nounFeatures(lizard,F).
lex(loaves,n,[agr([3,pl,n])|F]) :- nounFeatures(loaf,F).
lex(locks,n,[agr([3,pl,n])|F]) :- nounFeatures(lock,F).
lex(lockets,n,[agr([3,pl,n])|F]) :- nounFeatures(locket,F).
lex(looks,n,[agr([3,pl,n])|F]) :- nounFeatures(look,F).
lex(losses,n,[agr([3,pl,n])|F]) :- nounFeatures(loss,F).
lex(machines,n,[agr([3,pl,n])|F]):- nounFeatures(machine,F).
lex(maids,n,[agr([3,pl,[m,f]])|F]):- nounFeatures(maid,F).
lex(mailboxes,n,[agr([3,pl,n])|F]):- nounFeatures(mailbox,F).
lex(managers,n,[agr([3,pl,[m,f]])|F]):- nounFeatures(manager,F).
lex(maps,n,[agr([3,pl,n])|F]):- nounFeatures(map,F).
lex(marbles,n,[agr([3,pl,n])|F]):- nounFeatures(marble,F).
lex(marks,n,[agr([3,pl,n])|F]):- nounFeatures(mark,F).
lex(markets,n,[agr([3,pl,n])|F]):- nounFeatures(market,F).
lex(masses,n,[agr([3,pl,n])|F]):- nounFeatures(mass,F).
lex(matches,n,[agr([3,pl,n])|F]):- nounFeatures(match,F).
lex(meals,n,[agr([3,pl,n])|F]):- nounFeatures(meal,F).
lex(measures,n,[agr([3,pl,n])|F]):- nounFeatures(measure,F).
lex(medals,n,[agr([3,pl,n])|F]):- nounFeatures(medal,F).
lex(mirrors,n,[agr([3,pl,n])|F]):- nounFeatures(mirror,F).
lex(men,n,[agr([3,pl,m])|F]):- nounFeatures(man,F).
lex(meetings,n,[agr([3,pl,n])|F]):- nounFeatures(meeting,F).
lex(memories,n,[agr([3,pl,n])|F]):- nounFeatures(memory,F).
lex(metals,n,[agr([3,pl,n])|F]):- nounFeatures(metal,F).
lex(middles,n,[agr([3,pl,n])|F]):- nounFeatures(middle,F).
lex(minds,n,[agr([3,pl,n])|F]):- nounFeatures(mind,F).
lex(ministers,n,[agr([3,pl,[m,f]])|F]):- nounFeatures(minister,F).
lex(mints,n,[agr([3,pl,n])|F]):- nounFeatures(mint,F).
lex(minutes,n,[agr([3,pl,n])|F]):- nounFeatures(minute,F).
lex(mittens,n,[agr([3,pl,n])|F]):- nounFeatures(mitten,F).
lex(months,n,[agr([3,pl,n])|F]):- nounFeatures(month,F).
lex(moons,n,[agr([3,pl,n])|F]):- nounFeatures(moon,F).
lex(mothers,n,[agr([3,pl,f])|F]) :- nounFeatures(mother,F).
lex(nails,n,[agr([3,pl,n])|F]) :- nounFeatures(nail,F).
lex(nations,n,[agr([3,pl,n])|F]) :- nounFeatures(nation,F).
lex(necks,n,[agr([3,pl,n])|F]) :- nounFeatures(neck,F).
lex(needs,n,[agr([3,pl,n])|F]) :- nounFeatures(need,F).
lex(needles,n,[agr([3,pl,n])|F]) :- nounFeatures(needle,F).
lex(nerves,n,[agr([3,pl,n])|F]) :- nounFeatures(nerve,F).
lex(nests,n,[agr([3,pl,n])|F]) :- nounFeatures(nest,F).
lex(nets,n,[agr([3,pl,n])|F]) :- nounFeatures(net,F).
lex(nights,n,[agr([3,pl,n])|F]) :- nounFeatures(night,F).
lex(noises,n,[agr([3,pl,n])|F]) :- nounFeatures(noise,F).
lex(noses,n,[agr([3,pl,n])|F]) :- nounFeatures(nose,F).
lex(notes,n,[agr([3,pl,n])|F]) :- nounFeatures(note,F).
lex(notebooks,n,[agr([3,pl,n])|F]) :- nounFeatures(notebook,F).
lex(numbers,n,[agr([3,pl,n])|F]) :- nounFeatures(number,F).
lex(nuts,n,[agr([3,pl,n])|F]) :- nounFeatures(nut,F).
lex(observations,n,[agr([3,pl,n])|F]) :- nounFeatures(observation,F).
lex(oceans,n,[agr([3,pl,n])|F]) :- nounFeatures(ocean,F).
lex(offers,n,[agr([3,pl,n])|F]) :- nounFeatures(offer,F).
lex(offices,n,[agr([3,pl,n])|F]) :- nounFeatures(office,F).
lex(officers,n,[agr([3,pl,n])|F]) :- nounFeatures(officer,F).
lex(operations,n,[agr([3,pl,n])|F]) :- nounFeatures(operation,F).
lex(opinions,n,[agr([3,pl,n])|F]) :- nounFeatures(opinion,F).
lex(oranges,n,[agr([3,pl,n])|F]) :- nounFeatures(orange,F).
lex(orders,n,[agr([3,pl,n])|F]) :- nounFeatures(order,F).
lex(organizations,n,[agr([3,pl,n])|F]) :- nounFeatures(organization,F).
lex(ornaments,n,[agr([3,pl,n])|F]) :- nounFeatures(ornament,F).
lex(ovens,n,[agr([3,pl,n])|F]) :- nounFeatures(oven,F).
lex(owls,n,[agr([3,pl,n])|F]) :- nounFeatures(owl,F).
lex(owners,n,[agr([3,pl,[]])|F]) :- nounFeatures(owner,F).
lex(pages,n,[agr([3,pl,n])|F]) :- nounFeatures(page,F).
lex(pails,n,[agr([3,pl,n])|F]) :- nounFeatures(pail,F).
lex(pancakes,n,[agr([3,pl,n])|F]) :- nounFeatures(pancake,F).
lex(pans,n,[agr([3,pl,n])|F]) :- nounFeatures(pan,F).
lex(pants,n,[agr([3,pl,n])|F]) :- nounFeatures(paper,F).
lex(papers,n,[agr([3,pl,n])|F]) :- nounFeatures(paper,F).
lex(parcels,n,[agr([3,pl,n])|F]) :- nounFeatures(parcel,F).
lex(parts,n,[agr([3,pl,n])|F]) :- nounFeatures(part,F).
lex(partners,n,[agr([3,pl,n])|F]) :- nounFeatures(partner,F).
lex(parties,n,[agr([3,pl,n])|F]) :- nounFeatures(party,F).
lex(passengers,n,[agr([3,pl,n])|F]) :- nounFeatures(passenger,F).
lex(patches,n,[agr([3,pl,n])|F]) :- nounFeatures(patch,F).
lex(payments,n,[agr([3,pl,n])|F]) :- nounFeatures(payment,F).
lex(paychecks,n,[agr([3,pl,n])|F]) :- nounFeatures(paycheck,F).
lex(pets,n,[agr([3,pl,n])|F]) :- nounFeatures(pet,F).
lex(pens,n,[agr([3,pl,n])|F]) :- nounFeatures(pen,F).
lex(pencils,n,[agr([3,pl,n])|F]) :- nounFeatures(pencil,F).
lex(people,n,[agr([3,pl,[m,f]])|F]) :- nounFeatures(person,F).
lex(pickles,n,[agr([3,pl,n])|F]) :- nounFeatures(pickle,F).
lex(pies,n,[agr([3,pl,n])|F]) :- nounFeatures(pie,F).
lex(pins,n,[agr([3,pl,n])|F]) :- nounFeatures(pin,F).
lex(pipes,n,[agr([3,pl,n])|F]) :- nounFeatures(pipe,F).
lex(pizzas,n,[agr([3,pl,n])|F]) :- nounFeatures(pizza,F).
lex(places,n,[agr([3,pl,n])|F]) :- nounFeatures(place,F).
lex(planes,n,[agr([3,pl,n])|F]) :- nounFeatures(plane,F).
lex(plans,n,[agr([3,pl,n])|F]) :- nounFeatures(plan,F).
lex(plants,n,[agr([3,pl,n])|F]) :- nounFeatures(plant,F).
lex(plates,n,[agr([3,pl,n])|F]) :- nounFeatures(plate,F).
lex(plays,n,[agr([3,pl,n])|F]) :- nounFeatures(play,F).
lex(playgrounds,n,[agr([3,pl,n])|F]) :- nounFeatures(playground,F).
lex(plots,n,[agr([3,pl,n])|F]) :- nounFeatures(plot,F).
lex(ploughs,n,[agr([3,pl,n])|F]) :- nounFeatures(plough,F).
lex(pockets,n,[agr([3,pl,n])|F]) :- nounFeatures(pocket,F).
lex(points,n,[agr([3,pl,n])|F]) :- nounFeatures(point,F).
lex(poisons,n,[agr([3,pl,n])|F]) :- nounFeatures(poison,F).
lex(policemen,n,[agr([3,pl,m])|F]) :- nounFeatures(policeman,F).
lex(pictures,n,[agr([3,pl,n])|F]) :- nounFeatures(picture,F).
lex(problems,n,[agr([3,pl,n])|F]) :- nounFeatures(problem,F).
lex(porters,n,[agr([3,pl,n])|F]) :- nounFeatures(porter,F).
lex(positions,n,[agr([3,pl,n])|F]) :- nounFeatures(position,F).
lex(pots,n,[agr([3,pl,n])|F]) :- nounFeatures(pot,F).
lex(potatoes,n,[agr([3,pl,n])|F]) :- nounFeatures(potato,F).
lex(powders,n,[agr([3,pl,n])|F]) :- nounFeatures(powder,F).
lex(prices,n,[agr([3,pl,n])|F]) :- nounFeatures(price,F).
lex(prints,n,[agr([3,pl,n])|F]) :- nounFeatures(print,F).
lex(prisms,n,[agr([3,pl,n])|F]) :- nounFeatures(prism,F).
lex(prizes,n,[agr([3,pl,n])|F]) :- nounFeatures(prize,F).
lex(processes,n,[agr([3,pl,n])|F]) :- nounFeatures(process,F).
lex(profits,n,[agr([3,pl,n])|F]) :- nounFeatures(profit,F).
lex(properties,n,[agr([3,pl,n])|F]) :- nounFeatures(property,F).
lex(proses,n,[agr([3,pl,n])|F]) :- nounFeatures(prose,F).
lex(protests,n,[agr([3,pl,n])|F]) :- nounFeatures(protest,F).
lex(pumps,n,[agr([3,pl,n])|F]) :- nounFeatures(pump,F).
lex(punishments,n,[agr([3,pl,n])|F]) :- nounFeatures(punishment,F).
lex(purposes,n,[agr([3,pl,n])|F]) :- nounFeatures(purpose,F).
lex(pushes,n,[agr([3,pl,n])|F]) :- nounFeatures(push,F).
lex(quarters,n,[agr([3,pl,n])|F]) :- nounFeatures(quarter,F).
lex(queens,n,[agr([3,pl,n])|F]) :- nounFeatures(queen,F).
lex(questions,n,[agr([3,pl,n])|F]) :- nounFeatures(question,F).
lex(quicksands,n,[agr([3,pl,n])|F]) :- nounFeatures(quicksand,F).
lex(quills,n,[agr([3,pl,n])|F]) :- nounFeatures(quill,F).
lex(quilts,n,[agr([3,pl,n])|F]) :- nounFeatures(quilt,F).
lex(quivers,n,[agr([3,pl,n])|F]) :- nounFeatures(quiver,F).
lex(rabbits,n,[agr([3,pl,n])|F]) :- nounFeatures(rabbit,F).
lex(rails,n,[agr([3,pl,n])|F]) :- nounFeatures(rail,F).
lex(railways,n,[agr([3,pl,n])|F]) :- nounFeatures(railway,F).
lex(rakes,n,[agr([3,pl,n])|F]) :- nounFeatures(rake,F).
lex(ranges,n,[agr([3,pl,n])|F]) :- nounFeatures(range,F).
lex(rats,n,[agr([3,pl,n])|F]) :- nounFeatures(rat,F).
lex(rates,n,[agr([3,pl,n])|F]) :- nounFeatures(rate,F).
lex(rays,n,[agr([3,pl,n])|F]) :- nounFeatures(ray,F).
lex(reactions,n,[agr([3,pl,n])|F]) :- nounFeatures(reaction,F).
lex(readings,n,[agr([3,pl,n])|F]) :- nounFeatures(reading,F).
lex(reasons,n,[agr([3,pl,n])|F]) :- nounFeatures(reason,F).
lex(receipts,n,[agr([3,pl,n])|F]) :- nounFeatures(receipt,F).
lex(recesses,n,[agr([3,pl,n])|F]) :- nounFeatures(recess,F).
lex(records,n,[agr([3,pl,n])|F]) :- nounFeatures(record,F).
lex(regrets,n,[agr([3,pl,n])|F]) :- nounFeatures(regret,F).
lex(relations,n,[agr([3,pl,n])|F]) :- nounFeatures(relation,F).
lex(religions,n,[agr([3,pl,n])|F]) :- nounFeatures(religion,F).
lex(reports,n,[agr([3,pl,n])|F]) :- nounFeatures(report,F).
lex(representatives,n,[agr([3,pl,n])|F]) :- nounFeatures(representative,F).
lex(requests,n,[agr([3,pl,n])|F]) :- nounFeatures(request,F).
lex(respects,n,[agr([3,pl,n])|F]) :- nounFeatures(respect,F).
lex(rests,n,[agr([3,pl,n])|F]) :- nounFeatures(rest,F).
lex(rewards,n,[agr([3,pl,n])|F]) :- nounFeatures(reward,F).
lex(rhythms,n,[agr([3,pl,n])|F]) :- nounFeatures(rhythm,F).
lex(riddles,n,[agr([3,pl,n])|F]) :- nounFeatures(riddle,F).
lex(rifles,n,[agr([3,pl,n])|F]) :- nounFeatures(rifle,F).
lex(rings,n,[agr([3,pl,n])|F]) :- nounFeatures(ring,F).
lex(rivers,n,[agr([3,pl,n])|F]) :- nounFeatures(river,F).
lex(roads,n,[agr([3,pl,n])|F]) :- nounFeatures(road,F).
lex(robins,n,[agr([3,pl,n])|F]) :- nounFeatures(robin,F).
lex(rocks,n,[agr([3,pl,n])|F]) :- nounFeatures(rock,F).
lex(rods,n,[agr([3,pl,n])|F]) :- nounFeatures(rod,F).
lex(rooves,n,[agr([3,pl,n])|F]) :- nounFeatures(roof,F).
lex(roses,n,[agr([3,pl,n])|F]) :- nounFeatures(rose,F).
lex(routes,n,[agr([3,pl,n])|F]) :- nounFeatures(route,F).
lex(rubs,n,[agr([3,pl,n])|F]) :- nounFeatures(rub,F).
lex(rules,n,[agr([3,pl,n])|F]) :- nounFeatures(rule,F).
lex(runs,n,[agr([3,pl,n])|F]) :- nounFeatures(run,F).
lex(rooms,n,[agr([3,pl,n])|F]) :- nounFeatures(room,F).
lex(sacks,n,[agr([3,pl,n])|F]) :- nounFeatures(sack,F).
lex(sails,n,[agr([3,pl,n])|F]) :- nounFeatures(sail,F).
lex(sands,n,[agr([3,pl,n])|F]) :- nounFeatures(sand,F).
lex(scales,n,[agr([3,pl,n])|F]) :- nounFeatures(scale,F).
lex(scarecrows,n,[agr([3,pl,n])|F]) :- nounFeatures(scarecrow,F).
lex(scarves,n,[agr([3,pl,n])|F]) :- nounFeatures(scarf,F).
lex(scenes,n,[agr([3,pl,n])|F]) :- nounFeatures(scene,F).
lex(scents,n,[agr([3,pl,n])|F]) :- nounFeatures(scent,F).
lex(schools,n,[agr([3,pl,n])|F]) :- nounFeatures(school,F).
lex(sciences,n,[agr([3,pl,n])|F]) :- nounFeatures(science,F).
lex(seats,n,[agr([3,pl,n])|F]) :- nounFeatures(seat,F).
lex(screws,n,[agr([3,pl,n])|F]) :- nounFeatures(screw,F).
lex(seas,n,[agr([3,pl,n])|F]) :- nounFeatures(sea,F).
lex(seashores,n,[agr([3,pl,n])|F]) :- nounFeatures(seashore,F).
lex(secretaries,n,[agr([3,pl,n])|F]) :- nounFeatures(secretary,F).
lex(seeds,n,[agr([3,pl,n])|F]) :- nounFeatures(seed,F).
lex(selections,n,[agr([3,pl,n])|F]) :- nounFeatures(selection,F).
lex(selves,n,[agr([3,pl,n])|F]) :- nounFeatures(self,F).
lex(senses,n,[agr([3,pl,n])|F]) :- nounFeatures(sense,F).
lex(servants,n,[agr([3,pl,n])|F]) :- nounFeatures(servant,F).
lex(shades,n,[agr([3,pl,n])|F]) :- nounFeatures(shade,F).
lex(shakes,n,[agr([3,pl,n])|F]) :- nounFeatures(shake,F).
lex(shapes,n,[agr([3,pl,n])|F]) :- nounFeatures(shape,F).
lex(sheets,n,[agr([3,pl,n])|F]) :- nounFeatures(sheet,F).
lex(shelves,n,[agr([3,pl,n])|F]) :- nounFeatures(shelf,F).
lex(ships,n,[agr([3,pl,n])|F]) :- nounFeatures(ship,F).
lex(shocks,n,[agr([3,pl,n])|F]) :- nounFeatures(shock,F).
lex(shops,n,[agr([3,pl,n])|F]) :- nounFeatures(shop,F).
lex(shows,n,[agr([3,pl,n])|F]) :- nounFeatures(show,F).
lex(sides,n,[agr([3,pl,n])|F]) :- nounFeatures(side,F).
lex(sidewalks,n,[agr([3,pl,n])|F]) :- nounFeatures(sidewalk,F).
lex(signs,n,[agr([3,pl,n])|F]) :- nounFeatures(sign,F).
lex(silks,n,[agr([3,pl,n])|F]) :- nounFeatures(silk,F).
lex(sinks,n,[agr([3,pl,n])|F]) :- nounFeatures(sink,F).
lex(skins,n,[agr([3,pl,n])|F]) :- nounFeatures(skin,F).
lex(skies,n,[agr([3,pl,n])|F]) :- nounFeatures(sky,F).
lex(slaves,n,[agr([3,pl,n])|F]) :- nounFeatures(slave,F).
lex(slopes,n,[agr([3,pl,n])|F]) :- nounFeatures(slope,F).
lex(smokes,n,[agr([3,pl,n])|F]) :- nounFeatures(smoke,F).
lex(snails,n,[agr([3,pl,n])|F]) :- nounFeatures(snail,F).
lex(snakes,n,[agr([3,pl,n])|F]) :- nounFeatures(snake,F).
lex(sneezes,n,[agr([3,pl,n])|F]) :- nounFeatures(sneeze,F).
lex(soaps,n,[agr([3,pl,n])|F]) :- nounFeatures(soap,F).
lex(societies,n,[agr([3,pl,n])|F]) :- nounFeatures(society,F).
lex(sodas,n,[agr([3,pl,n])|F]) :- nounFeatures(soda,F).
lex(sofas,n,[agr([3,pl,n])|F]) :- nounFeatures(sofa,F).
lex(songs,n,[agr([3,pl,n])|F]) :- nounFeatures(song,F).
lex(sounds,n,[agr([3,pl,n])|F]) :- nounFeatures(sound,F).
lex(spaces,n,[agr([3,pl,n])|F]) :- nounFeatures(space,F).
lex(spades,n,[agr([3,pl,n])|F]) :- nounFeatures(spade,F).
lex(sparks,n,[agr([3,pl,n])|F]) :- nounFeatures(spark,F).
lex(spiders,n,[agr([3,pl,n])|F]) :- nounFeatures(spider,F).
lex(sponges,n,[agr([3,pl,n])|F]) :- nounFeatures(sponge,F).
lex(spoons,n,[agr([3,pl,n])|F]) :- nounFeatures(spoon,F).
lex(spots,n,[agr([3,pl,n])|F]) :- nounFeatures(spot,F).
lex(springs,n,[agr([3,pl,n])|F]) :- nounFeatures(spring,F).
lex(squares,n,[agr([3,pl,n])|F]) :- nounFeatures(square,F).
lex(squirrels,n,[agr([3,pl,n])|F]) :- nounFeatures(squirrel,F).
lex(stages,n,[agr([3,pl,n])|F]) :- nounFeatures(stage,F).
lex(stamps,n,[agr([3,pl,n])|F]) :- nounFeatures(stamp,F).
lex(stars,n,[agr([3,pl,n])|F]) :- nounFeatures(star,F).
lex(statements,n,[agr([3,pl,n])|F]) :- nounFeatures(statement,F).
lex(stations,n,[agr([3,pl,n])|F]) :- nounFeatures(station,F).
lex(stems,n,[agr([3,pl,n])|F]) :- nounFeatures(stem,F).
lex(steps,n,[agr([3,pl,n])|F]) :- nounFeatures(step,F).
lex(stews,n,[agr([3,pl,n])|F]) :- nounFeatures(stew,F).
lex(sticks,n,[agr([3,pl,n])|F]) :- nounFeatures(stick,F).
lex(stitches,n,[agr([3,pl,n])|F]) :- nounFeatures(stitch,F).
lex(stockings,n,[agr([3,pl,n])|F]) :- nounFeatures(stocking,F).
lex(stomaches,n,[agr([3,pl,n])|F]) :- nounFeatures(stomach,F).
lex(stones,n,[agr([3,pl,n])|F]) :- nounFeatures(stone,F).
lex(stores,n,[agr([3,pl,n])|F]) :- nounFeatures(store,F).
lex(stories,n,[agr([3,pl,n])|F]) :- nounFeatures(story,F).
lex(stones,n,[agr([3,pl,n])|F]) :- nounFeatures(stone,F).
lex(strangers,n,[agr([3,pl,n])|F]) :- nounFeatures(stranger,F).
lex(straws,n,[agr([3,pl,n])|F]) :- nounFeatures(straw,F).
lex(streams,n,[agr([3,pl,n])|F]) :- nounFeatures(stream,F).
lex(stretches,n,[agr([3,pl,n])|F]) :- nounFeatures(stretch,F).
lex(streets,n,[agr([3,pl,n])|F]) :- nounFeatures(street,F).
lex(strings,n,[agr([3,pl,n])|F]) :- nounFeatures(string,F).
lex(structures,n,[agr([3,pl,n])|F]) :- nounFeatures(structure,F).
lex(substances,n,[agr([3,pl,n])|F]) :- nounFeatures(substance,F).
lex(suggestions,n,[agr([3,pl,n])|F]) :- nounFeatures(scowl,F).
lex(suits,n,[agr([3,pl,n])|F]) :- nounFeatures(suit,F).
lex(summers,n,[agr([3,pl,n])|F]) :- nounFeatures(summer,F).
lex(suns,n,[agr([3,pl,n])|F]) :- nounFeatures(sun,F).
lex(supports,n,[agr([3,pl,n])|F]) :- nounFeatures(support,F).
lex(surprises,n,[agr([3,pl,n])|F]) :- nounFeatures(surprise,F).
lex(sweaters,n,[agr([3,pl,n])|F]) :- nounFeatures(sweater,F).
lex(swings,n,[agr([3,pl,n])|F]) :- nounFeatures(swing,F).
lex(systems,n,[agr([3,pl,n])|F]) :- nounFeatures(system,F).
lex(sandwiches,n,[agr([3,pl,n])|F]) :- nounFeatures(sandwich,F).
lex(scowls,n,[agr([3,pl,n])|F]) :- nounFeatures(scowl,F).
lex(shirts,n,[agr([3,pl,n])|F]) :- nounFeatures(shirt,F).
lex(shoes,n,[agr([3,pl,n])|F]) :- nounFeatures(shoe,F).
lex(smiles,n,[agr([3,pl,n])|F]) :- nounFeatures(smile,F).
lex(socks,n,[agr([3,pl,n])|F]) :- nounFeatures(sock,F).
lex(soldiers,n,[agr([3,pl,n])|F]) :- nounFeatures(soldier,F).
lex(soups,n,[agr([3,pl,n])|F]) :- nounFeatures(soup,F).
lex(stains,n,[agr([3,pl,n])|F]) :- nounFeatures(stain,F).
lex(students,n,[agr([3,pl,[m,f]])|F]) :- nounFeatures(student,F).
lex(symphonies,n,[agr([3,pl,n])|F]) :- nounFeatures(symphony,F).
lex(tables,n,[agr([3,pl,n])|F]) :- nounFeatures(table,F).
lex(tails,n,[agr([3,pl,n])|F]) :- nounFeatures(tail,F).
lex(talks,n,[agr([3,pl,n])|F]) :- nounFeatures(talk,F).
lex(tanks,n,[agr([3,pl,n])|F]) :- nounFeatures(tank,F).
lex(tastes,n,[agr([3,pl,n])|F]) :- nounFeatures(taste,F).
lex(taxes,n,[agr([3,pl,n])|F]) :- nounFeatures(tax,F).
lex(teams,n,[agr([3,pl,n])|F]) :- nounFeatures(team,F).
lex(teeth,n,[agr([3,pl,n])|F]) :- nounFeatures(tooth,F).
lex(tempers,n,[agr([3,pl,n])|F]) :- nounFeatures(temper,F).
lex(tendencies,n,[agr([3,pl,n])|F]) :- nounFeatures(tendency,F).
lex(tents,n,[agr([3,pl,n])|F]) :- nounFeatures(tent,F).
lex(territories,n,[agr([3,pl,n])|F]) :- nounFeatures(territory,F).
lex(tests,n,[agr([3,pl,n])|F]) :- nounFeatures(test,F).
lex(textures,n,[agr([3,pl,n])|F]) :- nounFeatures(texture,F).
lex(theories,n,[agr([3,pl,n])|F]) :- nounFeatures(theory,F).
lex(things,n,[agr([3,pl,n])|F]) :- nounFeatures(thing,F).
lex(thoughts,n,[agr([3,pl,n])|F]) :- nounFeatures(thought,F).
lex(threads,n,[agr([3,pl,n])|F]) :- nounFeatures(thread,F).
lex(thrills,n,[agr([3,pl,n])|F]) :- nounFeatures(thrill,F).
lex(throats,n,[agr([3,pl,n])|F]) :- nounFeatures(throat,F).
lex(thrones,n,[agr([3,pl,n])|F]) :- nounFeatures(throne,F).
lex(thumbs,n,[agr([3,pl,n])|F]) :- nounFeatures(thumb,F).
lex(tickets,n,[agr([3,pl,n])|F]) :- nounFeatures(ticket,F).
lex(tigers,n,[agr([3,pl,n])|F]) :- nounFeatures(tiger,F).
lex(titles,n,[agr([3,pl,n])|F]) :- nounFeatures(title,F).
lex(toads,n,[agr([3,pl,n])|F]) :- nounFeatures(toad,F).
lex(toes,n,[agr([3,pl,n])|F]) :- nounFeatures(toe,F).
lex(tomatoes,n,[agr([3,pl,n])|F]) :- nounFeatures(tomato,F).
lex(tongues,n,[agr([3,pl,n])|F]) :- nounFeatures(tongue,F).
lex(towns,n,[agr([3,pl,n])|F]) :- nounFeatures(town,F).
lex(toys,n,[agr([3,pl,n])|F]) :- nounFeatures(toy,F).
lex(trails,n,[agr([3,pl,n])|F]) :- nounFeatures(trail,F).
lex(trains,n,[agr([3,pl,n])|F]) :- nounFeatures(train,F).
lex(tramps,n,[agr([3,pl,n])|F]) :- nounFeatures(tramp,F).
lex(transports,n,[agr([3,pl,n])|F]) :- nounFeatures(transport,F).
lex(trays,n,[agr([3,pl,n])|F]) :- nounFeatures(tray,F).
lex(trees,n,[agr([3,pl,n])|F]) :- nounFeatures(tree,F).
lex(tricks,n,[agr([3,pl,n])|F]) :- nounFeatures(trick,F).
lex(troubles,n,[agr([3,pl,n])|F]) :- nounFeatures(trouble,F).
lex(trucks,n,[agr([3,pl,n])|F]) :- nounFeatures(truck,F).
lex(tubs,n,[agr([3,pl,n])|F]) :- nounFeatures(tub,F).
lex(turkies,n,[agr([3,pl,n])|F]) :- nounFeatures(turkey,F).
lex(turns,n,[agr([3,pl,n])|F]) :- nounFeatures(turn,F).
lex(twigs,n,[agr([3,pl,n])|F]) :- nounFeatures(twig,F).
lex(twists,n,[agr([3,pl,n])|F]) :- nounFeatures(twist,F).
lex(umbrellas,n,[agr([3,pl,n])|F]) :- nounFeatures(umbrella,F).
lex(units,n,[agr([3,pl,n])|F]) :- nounFeatures(unit,F).
lex(uses,n,[agr([3,pl,n])|F]) :- nounFeatures(use,F).
lex(teachers,n,[agr([3,pl,[m,f]])|F]) :- nounFeatures(teacher,F).
lex(telescopes,n,[agr([3,pl,n])|F]) :- nounFeatures(telescope,F).
lex(unicorns,n,[agr([3,pl,n])|F]):- nounFeatures(unicorn,F).
lex(universities,n,[agr([3,pl,n])|F]) :- nounFeatures(university,F).
lex(vacations,n,[agr([3,pl,n])|F]) :- nounFeatures(vacation,F).
lex(values,n,[agr([3,pl,n])|F]) :- nounFeatures(value,F).
lex(vans,n,[agr([3,pl,n])|F]) :- nounFeatures(van,F).
lex(vases,n,[agr([3,pl,n])|F]) :- nounFeatures(vase,F).
lex(vegetables,n,[agr([3,pl,n])|F]) :- nounFeatures(vegetable,F).
lex(veins,n,[agr([3,pl,n])|F]) :- nounFeatures(vein,F).
lex(veils,n,[agr([3,pl,n])|F]) :- nounFeatures(veil,F).
lex(verses,n,[agr([3,pl,n])|F]) :- nounFeatures(verse,F).
lex(vessels,n,[agr([3,pl,n])|F]) :- nounFeatures(vessel,F).
lex(vests,n,[agr([3,pl,n])|F]) :- nounFeatures(vest,F).
lex(views,n,[agr([3,pl,n])|F]) :- nounFeatures(view,F).
lex(visitors,n,[agr([3,pl,n])|F]) :- nounFeatures(visitor,F).
lex(voices,n,[agr([3,pl,n])|F]) :- nounFeatures(voice,F).
lex(volcanos,n,[agr([3,pl,n])|F]) :- nounFeatures(volcano,F).
lex(volleyballs,n,[agr([3,pl,n])|F]) :- nounFeatures(volleyball,F).
lex(voyages,n,[agr([3,pl,n])|F]) :- nounFeatures(voyage,F).
lex(walks,n,[agr([3,pl,n])|F]) :- nounFeatures(walk,F).
lex(walls,n,[agr([3,pl,n])|F]) :- nounFeatures(wall,F).
lex(wars,n,[agr([3,pl,n])|F]) :- nounFeatures(war,F).
lex(washes,n,[agr([3,pl,n])|F]) :- nounFeatures(wash,F).
lex(watches,n,[agr([3,pl,n])|F]) :- nounFeatures(watch,F).
lex(waters,n,[agr([3,pl,n])|F]) :- nounFeatures(water,F).
lex(waves,n,[agr([3,pl,n])|F]) :- nounFeatures(wave,F).
lex(waxes,n,[agr([3,pl,n])|F]) :- nounFeatures(wax,F).
lex(ways,n,[agr([3,pl,n])|F]) :- nounFeatures(way,F).
lex(weeks,n,[agr([3,pl,n])|F]) :- nounFeatures(week,F).
lex(weights,n,[agr([3,pl,n])|F]) :- nounFeatures(weight,F).
lex(wheels,n,[agr([3,pl,n])|F]) :- nounFeatures(wheel,F).
lex(whips,n,[agr([3,pl,n])|F]) :- nounFeatures(whip,F).
lex(whistles,n,[agr([3,pl,n])|F]) :- nounFeatures(whistle,F).
lex(windows,n,[agr([3,pl,n])|F]) :- nounFeatures(window,F).
lex(wings,n,[agr([3,pl,n])|F]) :- nounFeatures(wing,F).
lex(winters,n,[agr([3,pl,n])|F]) :- nounFeatures(winter,F).
lex(wires,n,[agr([3,pl,n])|F]) :- nounFeatures(wire,F).
lex(wishs,n,[agr([3,pl,n])|F]) :- nounFeatures(wish,F).
lex(words,n,[agr([3,pl,n])|F]) :- nounFeatures(word,F).
lex(works,n,[agr([3,pl,n])|F]) :- nounFeatures(work,F).
lex(worms,n,[agr([3,pl,n])|F]) :- nounFeatures(worm,F).
lex(wounds,n,[agr([3,pl,n])|F]) :- nounFeatures(wound,F).
lex(wrenches,n,[agr([3,pl,n])|F]) :- nounFeatures(wrench,F).
lex(wrists,n,[agr([3,pl,n])|F]) :- nounFeatures(wrist,F).
lex(writers,n,[agr([3,pl,n])|F]) :- nounFeatures(writer,F).
lex(writings,n,[agr([3,pl,n])|F]) :- nounFeatures(writing,F).
lex(women,n,[agr([3,pl,f])|F]) :- nounFeatures(woman,F).
lex(workers,n,[agr([3,pl,[m,f]])|F]) :- nounFeatures(worker,F).
lex(years,n,[agr([3,pl,n])|F]) :- nounFeatures(year,F).
lex(yaks,n,[agr([3,pl,n])|F]) :- nounFeatures(yak,F).
lex(yams,n,[agr([3,pl,n])|F]) :- nounFeatures(yam,F).
lex(yards,n,[agr([3,pl,n])|F]) :- nounFeatures(yard,F).
lex(yokes,n,[agr([3,pl,n])|F]) :- nounFeatures(yoke,F).
lex(zebras,n,[agr([3,pl,n])|F]) :- nounFeatures(zebra,F).
lex(zephyrs,n,[agr([3,pl,n])|F]) :- nounFeatures(zephyr,F).
lex(zippers,n,[agr([3,pl,n])|F]) :- nounFeatures(zipper,F).
lex(zoos,n,[agr([3,pl,n])|F]) :- nounFeatures(zoo,F).


% Nominalized verbs
lex(belief,n,[case(_),theta(_),count(+),agr([3,sg,n]),a(-),p(-)|F]) :-
	verbToNounFeatures(believe,F).
lex(claim,n,[case(_),theta(_),count(+),agr([3,sg,n]),a(-),p(-)|F]) :-
	verbToNounFeatures(claim,F).
lex(complaint,n,[case(_),theta(_),count(+),agr([3,sg,[]]),a(-),p(-)|F]) :-
	verbToNounFeatures(complain,F).
lex(departure,n,[case(_),theta(_),count(+),agr([3,sg,n]),a(-),p(-)|F]) :-
	verbToNounFeatures(depart,F).
lex(destruction,n,[case(_),theta(_),count(-),agr([3,m,n]),a(-),p(-)|F]) :-
	verbToNounFeatures(destroy,F).
lex(fight,n,[case(_),theta(_),count(+),agr([3,sg,[]]),a(-),p(-)|F]) :-
	verbToNounFeatures(fight,F).
lex(frown,n,[case(_),theta(_),count(+),agr([3,sg,[]]),a(-),p(-)|F]) :-
	verbToNounFeatures(frown,F).
lex(plot,n,[case(_),theta(_),count(+),agr([3,sg,[]]),a(-),p(-)|F]) :-
	verbToNounFeatures(plot,F).
lex(scowl,n,[case(_),theta(_),count(+),agr([3,sg,[]]),a(-),p(-)|F]) :-
	verbToNounFeatures(scowl,F).
lex(smile,n,[case(_),theta(_),count(+),agr([3,sg,[]]),a(-),p(-)|F]) :-
	verbToNounFeatures(smile,F).


%%% VERBS - BASE FORMS
%
% Obligatory Elements
%	1. grid(Ext,Int) denotes the O-grid
%	2. morph(Base,[]/ing/s/ed(1)/ed(2))
% Optional Features
%	1. ecm(opt/oblig) for ECM verbs
%	2. noCasemark(+) for technically intransitive verbs
%	3. subcat(C$Fs,Fs1) subcategorizes for an element of category C
%	   with feature restriction list Fs.
%	   Feature list Fs1 will be appended to the feature list of C
%	4. selR(Rs), selR(Type,R) restriction(s) Rs or R on direct object.

lex(appear,v,[morph(appear,[]),grid([],[theme]),noCasemark(+),allowExt(destination)]).
lex(appreciate,v,[morph(appreciate,[]),grid([experiencer],[theme])]).
lex(arrest,v,[morph(arrest,[]),grid([agent],[patient])]).
lex(arrive,v,[morph(arrive,[]),grid([],[theme]),noCasemark(+)]).
lex(ask,v,[morph(ask,[]),grid([agent],[proposition]),
	   selR(head(c2),feature(wh(+)))]).
lex(award,v,[morph(award,[]),grid([agent],[theme])]).
lex(become,v,[morph(become,[]),grid([agent],[theme])]).
lex(begin,v,[morph(begin,[]),grid([agent],[[theme]])]).
lex(behave,v,[morph(behave,[]),grid([theme],[]),
	      allowExt(patient),requiresExt(manner)]).
lex(believe,v,[morph(believe,[]),grid([agent],[proposition]),ecm(oblig),
	       selR(head(c2),feature(wh(-)))]).
lex(bite,v,[morph(bite,[]),grid([agent],[patient])]).
lex(buy,v,[morph(buy,[]),grid([agent],[theme])]).
lex(call,v,[morph(call,[]),grid([agent],[[goal]])]).
lex(care,v,[morph(care,[]),grid([agent],[proposition]),
	    selR(head(c2),feature(wh(+))),noCasemark(_)]).
lex(claim,v,[morph(claim,[]),grid([agent],[proposition]),ecm(oblig),
	     selR(head(c2),feature(wh(-)))]).
lex(click,v,[morph(click,[]),grid([agent],[[theme]])]).
lex(come,v,[morph(come,[]),grid([agent],[]),allowExt(destination)]).
lex(complain,v,[morph(complain,[]),grid([agent],[])]). % allows about
lex(consider,v,[morph(consider,[]),grid([agent],[[theme]])]).
lex(cook,v,[morph(cook,[]),grid([agent],[patient])]).
lex(create,v,[morph(create,[]),grid([agent],[theme])]).
lex(depart,v,[morph(depart,[]),grid([agent],[])]).
lex(destroy,v,[morph(destroy,[]),grid([agent],[patient])]).
lex(die,v,[morph(die,[]),grid([],[theme]),noCasemark(+)]).
lex(disappear,v,[morph(disappear,[]),grid([],[theme]),noCasemark(+)]).
lex(eat,v,[morph(eat,[]),grid([agent],[[theme]])]).
lex(fall,v,[morph(fall,[]),grid([],[theme]),noCasemark(+)]).
lex(feel,v,[morph(feel,[]),grid([experiencer],[[theme]])]).
lex(fight,v,[morph(fight,[]),grid([agent],[[patient]])]). % also theme
lex(file,v,[morph(file,[]),grid([agent],[[patient]])]).
lex(find,v,[morph(find,[]),grid([agent],[theme]),allowExt(destination)]).
lex(find,v,[morph(find,[]),grid([agent],[theme]),idoCase(acc)]).
lex(fire,v,[morph(fire,[]),grid([agent],[patient])]).
lex(fix,v,[morph(fix,[]),grid([agent],[patient])]).
lex(frown,v,[morph(frown,[]),grid([agent],[])]).
lex(give,v,[morph(give,[]),grid([agent],[theme]),allowExt(destination)]).
lex(give,v,[morph(give,[]),grid([agent],[goal,theme]),idoCase(acc)]).
lex(hear,v,[morph(hear,[]),grid([perceiver],[[theme]])]).
lex(hang,v,[morph(hang,[]),grid([agent],[theme])]).
lex(help,v,[morph(help,[]),grid([agent],[beneficiary]),allowExt(goal)]).
lex(hinder,v,[morph(hinder,[]),grid([agent],[patient])]).
lex(hire,v,[morph(hire,[]),grid([agent],[patient])]).
lex(hit,v,[morph(hit,[]),grid([agent],[patient])]).
lex(instruct,v,[morph(instruct,[]),grid([agent],[[patient]])]).
lex(insult,v,[morph(insult,[]),grid([agent],[experiencer])]).
lex(keep,v,[morph(keep,[]),grid([agent],[theme])]).
lex(kill,v,[morph(kill,[]),grid([agent],[patient])]).
lex(know,v,[morph(know,[]),grid([agent],[[proposition]])]).
lex(laugh,v,[morph(laugh,[]),grid([agent],[]),allowExt(patient)]).
lex(leave,v,[morph(leave,[]),grid([agent],[[location]])]).
lex(lead,v,[morph(lead,[]),grid([agent],[patient])]).
lex(let,v,[morph(let,[]),grid([agent],[patient,theme]),idoCase(acc)]).
lex(look,v,[morph(look,[]),grid([agent],[]),allowExt(theme)]).
lex(like,v,[morph(like,[]),grid([agent],[theme])]).
lex(lose,v,[morph(lose,[]),grid([agent],[[theme]])]).
lex(love,v,[morph(love,[]),grid([experiencer],[[theme]])]).
lex(meet,v,[morph(meet,[]),grid([agent],[patient])]). % object is agent-like too
lex(mention,v,[morph(mention,[]),grid([agent],[proposition]),
	       selR(head(c2),feature(wh(-)))]).
lex(murder,v,[morph(murder,[]),grid([agent],[patient])]).
lex(need,v,[morph(need,[]),grid([cognizer],[theme])]).
lex(need,v,[morph(need,[]),grid([cognizer],[proposition]),ecm(opt)]).
lex(own,v,[morph(own,[]),grid([agent],[theme])]).
lex(park,v,[morph(park,[]),grid([agent],[[theme]])]).
lex(persuade,v,[morph(persuade,[]),grid([agent],[goal,proposition]),
		iselR(not(feature(wh(+))))]).
lex(pet,v,[morph(pet,[]),grid([agent],[theme])]).
lex(please,v,[morph(please,[]),grid([agent],[experiencer])]).
lex(plot,v,[morph(plot,[]),grid([agent],[[theme]])]).
lex(promise,v,[morph(promise,[]),grid([agent],[patient,proposition]),
	       selR([addFeature(noControl)]),iselR(not(feature(wh(+))))]). 
lex(punch,v,[morph(punch,[]),grid([agent],[patient])]).
lex(put,v,[morph(put,[]),grid([agent],[patient]),requiresExt(location)]).
lex(rain,v,[morph(rain,[]),grid([],[]),allowExt(location)]).
lex(read,v,[morph(read,[]),grid([agent],[[theme]])]).
lex(remove,v,[morph(remove,[]),grid([agent],[[theme]])]).
lex(resign,v,[morph(resign,[]),grid([agent],[]),allowExt(location)]).
lex(run,v,[morph(run,[]),grid([agent],[])]).
lex(say,v,[morph(say,[]),grid([agent],[proposition]),
	   selR(head(c2),feature(wh(-))),noCasemark(_)]).
lex(scowl,v,[morph(scowl,[]),grid([agent],[])]).
lex(search,v,[morph(search,[]),grid([agent],[[theme]])]).
lex(see,v,[morph(see,[]),grid([perceiver],[[theme]])]).
lex(seek,v,[morph(seek,[]),grid([agent],[goal])]).
lex(seem,v,[morph(seem,[]),grid([],[proposition]),
	    selR(head(c2),feature(wh(-))),ecm(oblig),noCasemark(_)]).
lex(send,v,[morph(send,[]),grid([agent],[recipient,theme]),idoCase(acc)]).
lex(shine,v,[morph(shine,[]),grid([source],[])]).
lex(show,v,[morph(show,[]),grid([agent],[recipient,theme]),idoCase(acc)]).
lex(sit,v,[morph(sit,[]),grid([agent],[]),allowExt(location)]).
lex(sleep,v,[morph(sleep,[]),grid([agent],[]),allowExt(location)]).
lex(smile,v,[morph(smile,[]),grid([agent],[])]).
lex(snow,v,[morph(snow,[]),grid([],[])]).
lex(solve,v,[morph(solve,[]),grid([agent],[theme])]).
lex(speak,v,[morph(speak,[]),grid([agent],[]),allowExt(destination)]).
lex(stand,v,[morph(stand,[]),grid([agent],[proposition]),
	     selR(head(c2),feature(wh(-)))]).
lex(start,v,[morph(start,[]),grid([agent],[[theme]])]).
lex(stir,v,[morph(stir,[]),grid([agent],[[theme]])]).
lex(study,v,[morph(study,[]),grid([agent],[[theme]])]).
lex(surprise,v,[morph(surprise,[]),grid([agent],[patient,proposition]),
		iselR(not(feature(wh(+)))),inoCasemark(+)]).
lex(talk,v,[morph(talk,[]),grid([agent],[]),allowExt(destination)]).
lex(taste,v,[morph(taste,[]),grid([experiencer],[theme])]). % see, hear: perceiver
lex(tell,v,[morph(tell,[]),grid([agent],[[patient]]),allowExt(proposition)]).
lex(think,v,[morph(think,[]),grid([agent],[proposition]),
	     selR(head(c2),feature(wh(-))),noCasemark(_)]).
lex(try,v,[morph(try,[]),grid([agent],[proposition]),
	     selR(head(c2),feature(wh(-))),noCasemark(_)]).
lex(type,v,[morph(type,[]),grid([agent],[[theme]]),allowExt(manner)]).
lex(understand,v,[morph(understand,[]),grid([cognizer],[[theme]])]).
lex(use,v,[morph(use,[]),grid([agent],[instrument])]).
lex(visit,v,[morph(visit,[]),grid([agent],[patient])]).
lex(wake,v,[morph(wake,[]),grid([agent],[[patient]])]).
lex(walk,v,[morph(walk,[]),grid([agent],[]),allowExt(destination)]).
lex(want,v,[morph(want,[]),grid([agent],[proposition]),ecm(opt)]).
lex(wave,v,[morph(wave,[]),grid([agent],[]),allowExt(destination)]).
lex(win,v,[morph(win,[]),grid([agent],[[theme]])]).
lex(wonder,v,[morph(wonder,[]),grid([agent],[proposition]),
	      selR(head(c2),feature(wh(+))),noCasemark(_)]).
lex(work,v,[morph(work,[]),grid([agent],[]),allow(adv,degree)]).
lex(worry,v,[morph(worry,[]),grid([experiencer],[[theme]]),allow(adv,degree)]).
lex(worry,v,[morph(worry,[]),grid([agent],[experiencer]),allow(adv,degree)]).
lex(write,v,[morph(write,[]),grid([agent],[[theme]])]).
lex(yawn,v,[morph(yawn,[]),grid([agent],[])]).
lex(yell,v,[morph(yell,[]),grid([agent],[]),allowExt(patient)]).

%% Auxiliaries


lex(be,v,[morph(be,[]),aux,
	  oneof(_,[[grid([eq],[eq])],
		   [grid([],[theme]),noCasemark(+),	% unicorn
		    selR([goal(overt(X),X)])],
		   [grid([pHolder(P)],subcat),subcat(adv$[predicate(P)],[])],
		   [subcat(ap$[grid(_,_)],[])],
		   [subcat(vp$[morph(_,ed(2)),grid([_],[_|_]),
			       not(noCasemark(+))], % clever block
			      [noCasemark(+)]),
		    blockTheta],
		   [subcat(vp$[morph(_,ing)],[prog])]])]).

% Stage 2
% lex(be,v,[morph(be,[]),aux,grid([eq],[eq])]).	  % john is the man
% lex(be,v,[morph(be,[]),aux,grid([pHolder(P)],subcat),	% john is here
%	  subcat(adv$[predicate(P)],[])]).
% Stage 1
% lex(be,v,[morph(be,[]),aux,subcat(ap$[grid(_,_)],[])]).	% john is dead
% lex(be,v,[morph(be,[]),aux,blockTheta,	  % john was arrested
%	  subcat(vp$[morph(_,ed(2))],[noCasemark(+)])]).
% lex(be,v,[morph(be,[]),aux,			  % john is
%	  subcat(vp$[morph(_,ing)],[prog])]).

lex(have,v,[morph(have,[]),aux,perf,subcat(vp$[morph(_,ed(2))],[perf])]).
lex(do,v,[morph(do,[]),aux,subcat(vp$[morph(_,[])],[])]).

lex(can,v,[morph(can,def(past(-))),aux,modal,
	   subcat(vp$[morph(_,[])],[])]).
lex(could,v,[morph(could,def(past(+))),aux,modal,
	     subcat(vp$[morph(_,[])],[])]).
lex(would,v,[morph(would,def(past(+))),aux,modal,
	     subcat(vp$[morph(_,[])],[])]).
lex(shall,v,[morph(will,def(past(-))),aux,modal,
	    subcat(vp$[morph(_,[])],[])]).
lex(should,v,[morph(should,def(past(+))),aux,modal,
	      subcat(vp$[morph(_,[])],[])]).
lex(will,v,[morph(will,def(past(-))),aux,modal,
	    subcat(vp$[morph(_,[])],[])]).

%% Adjectives
%%

lex(aaaaa,a,[grid([],[patient])]).		% too complicated to explain
lex(able,a,[grid([],[proposition])]).
lex(black,a,[grid([theme],[])]).
lex(blue,a,[grid([theme],[])]).
lex(certain,a,[grid([],[proposition]),ecm(oblig)]).
lex(clever,a,[grid([theme],[])]).
lex(cloudy,a,[grid([theme],[])]).
lex(crazy,a,[grid([theme],[])]).
lex(crucial,a,[grid([],[proposition]),noCasemark(+)]).
lex(dumb,a,[grid([theme],[])]).
lex(eager,a,[grid([theme],[proposition]),noCasemark(_)]).
lex(eastern,a,[grid([theme],[])]).
lex(easy,a,[grid([],[proposition]),noCasemark(+)]).
lex(gold,a,[grid([theme],[])]).
lex(green,a,[grid([theme],[])]).
lex(hard,a,[grid([],[proposition]),noCasemark(+)]).
lex(happy,a,[grid([experiencer],[])]).
lex(honest,a,[grid([theme],[])]).
lex(illegal,a,[grid([],[proposition]),noCasemark(+)]).
lex(ill_founded,a,[grid([theme],[])]).
lex(illogical,a,[grid([theme],[])]).
lex(important,a,[grid([],[proposition]),noCasemark(+)]).
lex(intelligent,a,[grid([theme],[])]).
lex(kind,a,[grid([theme],[])]).
lex(likely,a,[grid([],[proposition]),ecm(oblig),noCasemark(+)]).
lex(nice,a,[grid([theme],[])]).
lex(northern,a,[grid([theme],[])]).
lex(on_sale,a,[grid([theme],[])]).
lex(orange,a,[grid([theme],[])]).
lex(pathological,a,[grid([theme],[])]).
lex(proud,a,[grid([theme],[proposition])]).
lex(purple,a,[grid([theme],[])]).
lex(rainy,a,[grid([theme],[])]).
lex(ready,a,[grid([theme],[]),allowExt(reason)]). % actually 'purpose'
lex(red,a,[grid([theme],[])]).
lex(rotten,a,[grid([theme],[])]).
lex(rowdy,a,[grid([theme],[])]).
lex(rude,a,[grid([theme],[])]).
lex(sad,a,[grid([theme],[])]).
lex(sick,a,[grid([theme],[])]).
lex(sickly,a,[grid([theme],[])]).
lex(silver,a,[grid([theme],[])]).
lex(southern,a,[grid([theme],[])]).
lex(stubborn,a,[grid([theme],[])]).
lex(sunny,a,[grid([theme],[])]).
lex(sweet,a,[grid([theme],[])]).
lex(thick,a,[grid([theme],[])]).
lex(thin,a,[grid([theme],[])]).
lex(thoughtful,a,[grid([theme],[])]).
lex(thoughtless,a,[grid([theme],[])]).
lex(tough,a,[grid(Role,[]),adjR([goal(inheritRole(X,Role),X)]),
	     allowExt(reason)]).
lex(western,a,[grid([theme],[])]).
lex(white,a,[grid([theme],[])]).
lex(yellow,a,[grid([theme],[])]).

% Complementizers
lex(for,c,[wh(-),ecm,selR([feature(inf([]))])]).
lex(that,c,[wh(-),selR([not(feature(inf(_))),
			not(feature(matrix))])]). % see definition in xbar
%	    specR(addFeature(noECP(ss)))]). % this is preventing the man that saw me...
lex(whether,c,[wh(+),specR(fail)]).		  % idea: whether in [Spec,CP]
lex(if,c,[wh(+)]).

% Markers: morphological realizations of particular features
lex(neg,mrkr,[left(v,aux,neg)]).		  % negation marker
lex(to,mrkr,[right(v,morph(_,[]),inf([]))]).	  % infinitival marker
lex(of,mrkr,[right(np,case(gen),[])]).		  % object genitive Case
lex(about,mrkr,[left(v,noCasemark(-),[])]).	  % Pesetsky 82

% subject of NP genitive Case
lex('''s',mrkr,[left(n,[not(morphC(_)),case(gen)],[])]).
lex('''',mrkr,[left(n,[not(morphC(_)),case(gen)],[])]).

% Coordinating conjunctions
lex(and,conj,[overt(+)]).

no lexFeature(_,_).

% relevant for marker constraints
relevant(n).
relevant(v).

irregular(be).

% Non-base verb forms:
%
% Form x Category x Base x Features

%% For regular forms

define_lex_forms.
ending(ing,ing).
ending(s,s).
ending(ed(_),ed).
ending(ed(1),ed).
ending(ed(2),en).

rootEnding(X+e,ing,X+ing).
rootEnding(X+e,ed,X+ed).
rootEnding(X+e,en,X+en).

lexTemplate(Root,C,Form,Infl,lex(Infl,C,Root,[morph(Root,Form)])).

lexForms(appear,v,[ing,s,ed(_)]).
lexForms(appreciate,v,[ing,s,ed(_)]).
lexForms(arrest,v,[ing,s,ed(_)]).
lexForms(arrive,v,[ing,s,ed(_)]).
lexForms(ask,v,[ing,s,ed(_)]).
lexForms(award,v,[ing,s,ed(_)]).
lexForms(behave,v,[ing,s,ed(_)]).
lexForms(believe,v,[ing,s,ed(_)]).
lexForms(call,v,[ing,s,ed(_)]).
lexForms(care,v,[ing,s,ed(_)]).
lexForms(claim,v,[ing,s,ed(_)]).
lexForms(click,v,[ing,s,ed(_)]).
lexForms(complain,v,[ing,s,ed(_)]).
lexForms(consider,v,[ing,s,ed(_)]).
lexForms(convey,v,[ing,s,ed(_)]).
lexForms(cook,v,[ing,s,ed(_)]).
lexForms(create,v,[ing,s,ed(_)]).
lexForms(depart,v,[ing,s,ed(_)]).
lexForms(destroy,v,[ing,s,ed(_)]).
lexForms(disappear,v,[ing,s,ed(_)]).
lexForms(display,v,[ing,s,ed(_)]).
lexForms(donate,v,[ing,s,ed(_)]).
lexForms(file,v,[ing,s,ed(_)]).
lexForms(fire,v,[ing,s,ed(_)]).
lexForms(flick,v,[ing,s,ed(_)]).
lexForms(frown,v,[ing,s,ed(_)]).
lexForms(help,v,[ing,s,ed(_)]).
lexForms(hinder,v,[ing,s,ed(_)]).
lexForms(hire,v,[ing,s,ed(_)]).
lexForms(hurl,v,[ing,s,ed(_)]).
lexForms(insult,v,[ing,s,ed(_)]).
lexForms(instruct,v,[ing,s,ed(_)]).
lexForms(kick,v,[ing,s,ed(_)]).
lexForms(kill,v,[ing,s,ed(_)]).
lexForms(laugh,v,[ing,s,ed(_)]).
lexForms(lift,v,[ing,s,ed(_)]).
lexForms(like,v,[ing,s,ed(_)]).
lexForms(look,v,[ing,s,ed(_)]).
lexForms(love,v,[ing,s,ed(_)]).
lexForms(lower,v,[ing,s,ed(_)]).
lexForms(mention,v,[ing,s,ed(_)]).
lexForms(murder,v,[ing,s,ed(_)]).
lexForms(need,v,[ing,s,ed(_)]).
lexForms(own,v,[ing,s,ed(_)]).
lexForms(park,v,[ing,s,ed(_)]).
lexForms(persuade,v,[ing,s,ed(_)]).
lexForms(please,v,[ing,s,ed(_)]).
lexForms(pull,v,[ing,s,ed(_)]).
lexForms(promise,v,[ing,s,ed(_)]).
lexForms(rain,v,[ing,s,ed(_)]).
lexForms(recount,v,[ing,s,ed(_)]).
lexForms(remove,v,[ing,s,ed(_)]).
lexForms(resign,v,[ing,s,ed(_)]).
lexForms(scowl,v,[ing,s,ed(_)]).
lexForms(seem,v,[ing,s,ed(_)]).
lexForms(smile,v,[ing,s,ed(_)]).
lexForms(snow,v,[ing,s,ed(_)]).
lexForms(solve,v,[ing,s,ed(_)]).
lexForms(start,v,[ing,s,ed(_)]).
lexForms(surprise,v,[ing,s,ed(_)]).
lexForms(talk,v,[ing,s,ed(_)]).
lexForms(taste,v,[ing,s,ed(_)]).
lexForms(telegraph,v,[ing,s,ed(_)]).
lexForms(type,v,[ing,s,ed(_)]).
lexForms(use,v,[ing,s,ed(_)]).
lexForms(visit,v,[ing,s,ed(_)]).
lexForms(walk,v,[ing,s,ed(_)]).
lexForms(want,v,[ing,s,ed(_)]).
lexForms(wave,v,[ing,s,ed(_)]).
lexForms(wire,v,[ing,s,ed(_)]).
lexForms(wonder,v,[ing,s,ed(_)]).
lexForms(work,v,[ing,s,ed(_)]).
lexForms(yawn,v,[ing,s,ed(_)]).
lexForms(yell,v,[ing,s,ed(_)]).

%% For irregular forms

lex(am,_,be,[morph(be,am)]).  % Cat=mrkr, aux
lex(are,_,be,[morph(be,are)]).
lex(been,_,be,[morph(be,ed(2))]).
lex(being,_,be,[morph(be,ing)]).
lex(is,_,be,[morph(be,s)]).
lex(was,_,be,[morph(be,was)]).
lex(were,_,be,[morph(be,were)]).

lex(becoming,v,become,[morph(become,ing)]).
lex(becomes,v,become,[morph(become,s)]).
lex(became,v,become,[morph(become,ed(_))]).

lex(beginning,v,begin,[morph(begin,ing)]).
lex(begins,v,begin,[morph(begin,s)]).
lex(began,v,begin,[morph(begin,ed(1))]).
lex(begun,v,begin,[morph(begin,ed(2))]).

lex(biting,v,bite,[morph(bite,ing)]).
lex(bites,v,bite,[morph(bite,s)]).
lex(bit,v,bite,[morph(bite,ed(1))]).
lex(bitten,v,bite,[morph(bite,ed(2))]).

lex(buying,v,buy,[morph(buy,ing)]).
lex(buys,v,buy,[morph(buy,s)]).
lex(bought,v,buy,[morph(buy,ed(_))]).

lex(coming,v,come,[morph(come,ing)]).
lex(comes,v,come,[morph(come,s)]).
lex(came,v,come,[morph(come,ed(_))]).

lex(denying,v,deny,[morph(deny,ing)]).
lex(denies,v,deny,[morph(deny,s)]).
lex(denied,v,deny,[morph(deny,ed(_))]).

lex(dragging,v,drag,[morph(drag,ing)]).
lex(drags,v,drag,[morph(drag,s)]).
lex(dragged,v,drag,[morph(drag,ed(_))]).

lex(driving,v,drive,[morph(drive,ing)]).
lex(drives,v,drive,[morph(drive,s)]).
lex(drove,v,drive,[morph(drive,ed(1))]).
lex(driven,v,drive,[morph(drive,ed(2))]).

lex(dying,v,die,[morph(die,ing)]).
lex(dies,v,die,[morph(die,s)]).
lex(died,v,die,[morph(die,ed(_))]).

lex(doing,_,do,[morph(do,ing)]).
lex(does,_,do,[morph(do,s)]).
lex(did,_,do,[morph(do,ed(1))]).
lex(done,_,do,[morph(do,ed(2))]).

lex(eating,v,eat,[morph(eat,ing)]).
lex(eats,v,eat,[morph(eat,s)]).
lex(ate,v,eat,[morph(eat,ed(1))]).
lex(eaten,v,eat,[morph(eat,ed(2))]).

lex(falling,v,fall,[morph(fall,ing)]).
lex(falls,v,fall,[morph(fall,s)]).
lex(fell,v,fall,[morph(fall,ed(1))]).
lex(fallen,v,fall,[morph(fall,ed(2))]).

lex(feeling,v,feel,[morph(feel,ing)]).
lex(feels,v,feel,[morph(feel,s)]).
lex(felt,v,feel,[morph(feel,ed(_))]).

lex(fighting,v,fight,[morph(fight,ing)]).
lex(fights,v,fight,[morph(fight,s)]).
lex(fought,v,fight,[morph(fight,ed(_))]).

lex(finding,v,find,[morph(find,ing)]).
lex(finds,v,find,[morph(find,s)]).
lex(found,v,find,[morph(find,ed(_))]).

lex(fixing,v,fix,[morph(fix,ing)]).
lex(fixes,v,fix,[morph(fix,s)]).
lex(fixed,v,fix,[morph(fix,ed(_))]).

lex(flinging,v,fling,[morph(fling,ing)]).
lex(flings,v,fling,[morph(fling,s)]).
lex(flung,v,fling,[morph(fling,ed(_))]).

lex(getting,v,get,[morph(get,ing)]).
lex(gets,v,get,[morph(get,s)]).
lex(got,v,get,[morph(get,ed(1))]).
lex(gotten,v,get,[morph(get,ed(2))]).

lex(giving,v,give,[morph(give,ing)]).
lex(gives,v,give,[morph(give,s)]).
lex(gave,v,give,[morph(give,ed(1))]).
lex(given,v,give,[morph(give,ed(2))]).

lex(having,_,have,[morph(have,ing)]).
lex(has,_,have,[morph(have,s)]).
lex(had,_,have,[morph(have,ed(_))]).

lex(hanging,v,hang,[morph(hang,ing)]).
lex(hangs,v,hang,[morph(hang,s)]).
lex(hung,v,hang,[morph(hang,ed(1))]).
lex(hanged,v,hang,[morph(hang,ed(2))]).

lex(hearing,v,hear,[morph(hear,ing)]).
lex(hears,v,hear,[morph(hear,s)]).
lex(heard,v,hear,[morph(hear,ed(_))]).

lex(hitting,v,hit,[morph(hit,ing)]).
lex(hits,v,hit,[morph(hit,s)]).
lex(hit,v,hit,[morph(hit,ed(_))]).

lex(keeping,v,keep,[morph(keep,ing)]).
lex(keeps,v,keep,[morph(keep,s)]).
lex(kept,v,keep,[morph(keep,ed(_))]).

lex(knowing,v,know,[morph(know,ing)]).
lex(knows,v,know,[morph(know,s)]).
lex(knew,v,know,[morph(know,ed(1))]).
lex(known,v,know,[morph(know,ed(2))]).

lex(leaving,v,leave,[morph(leave,ing)]).
lex(leaves,v,leave,[morph(leave,s)]).
lex(left,v,leave,[morph(leave,ed(_))]).

lex(leading,v,lead,[morph(lead,ing)]).
lex(leads,v,lead,[morph(lead,s)]).
lex(led,v,lead,[morph(lead,ed(_))]).

lex(letting,v,let,[morph(let,ing)]).
lex(lets,v,let,[morph(let,s)]).
lex(let,v,let,[morph(let,ed(_))]).

lex(losing,v,lose,[morph(lose,ing)]).
lex(loses,v,lose,[morph(lose,s)]).
lex(lost,v,lose,[morph(lose,ed(_))]).

lex(meeting,v,meet,[morph(meet,ing)]).
lex(meets,v,meet,[morph(meet,s)]).
lex(met,v,meet,[morph(meet,ed(_))]).

lex(petting,v,pet,[morph(pet,ing)]).
lex(pets,v,pet,[morph(pet,s)]).
lex(pet,v,pet,[morph(pet,ed(_))]).

lex(plotting,v,plot,[morph(plot,ing)]).
lex(plots,v,plot,[morph(plot,s)]).
lex(plotted,v,plot,[morph(plot,ed(_))]).

lex(punching,v,punch,[morph(punch,ing)]).
lex(punches,v,punch,[morph(punch,s)]).
lex(punched,v,punch,[morph(punch,ed(_))]).

lex(pushing,v,push,[morph(push,ing)]).
lex(pushes,v,push,[morph(push,s)]).
lex(pushed,v,push,[morph(push,ed(_))]).

lex(putting,v,put,[morph(put,ing)]).
lex(puts,v,put,[morph(put,s)]).
lex(put,v,put,[morph(put,ed(_))]).

lex(reading,v,read,[morph(read,ing)]).
lex(reads,v,read,[morph(read,s)]).
lex(read,v,read,[morph(read,ed(_))]).

lex(running,v,run,[morph(run,ing)]).
lex(runs,v,run,[morph(run,s)]).
lex(ran,v,run,[morph(run,ed(_))]).

lex(saying,v,say,[morph(say,ing)]).
lex(says,v,say,[morph(say,s)]).
lex(said,v,say,[morph(say,ed(_))]).

lex(seeing,v,see,[morph(see,ing)]).
lex(sees,v,see,[morph(see,s)]).
lex(saw,v,see,[morph(see,ed(1))]).
lex(seen,v,see,[morph(see,ed(2))]).

lex(seeking,v,seek,[morph(seek,ing)]).
lex(seeks,v,seek,[morph(seek,s)]).
lex(sought,v,seek,[morph(seek,ed(_))]).

lex(searching,v,search,[morph(search,ing)]).
lex(searches,v,search,[morph(search,s)]).
lex(searched,v,search,[morph(search,ed(_))]).

lex(sending,v,send,[morph(send,ing)]).
lex(sends,v,send,[morph(send,s)]).
lex(sent,v,send,[morph(send,ed(_))]).

lex(shining,v,shine,[morph(shine,ing)]).
lex(shines,v,shine,[morph(shine,s)]).
lex(shone,v,shine,[morph(shine,ed(_))]).

lex(showing,v,show,[morph(show,ing)]).
lex(shows,v,show,[morph(show,s)]).
lex(showed,v,show,[morph(show,ed(1))]).
lex(shown,v,show,[morph(show,ed(2))]).

lex(sitting,v,sit,[morph(sit,ing)]).
lex(sits,v,sit,[morph(sit,s)]).
lex(sat,v,sit,[morph(sit,ed(_))]).

lex(sleeping,v,sleep,[morph(sleep,ing)]).
lex(sleeps,v,sleep,[morph(sleep,s)]).
lex(slept,v,sleep,[morph(sleep,ed(_))]).

lex(shlepping,v,shlep,[morph(shlep,ing)]).
lex(shleps,v,shlep,[morph(shlep,s)]).
lex(shlepped,v,shlep,[morph(shlep,ed(_))]).

lex(standing,v,stand,[morph(stand,ing)]).
lex(stands,v,stand,[morph(stand,s)]).
lex(stood,v,stand,[morph(stand,ed(_))]).

lex(stirring,v,stir,[morph(stir,ing)]).
lex(stirs,v,stir,[morph(stir,s)]).
lex(stirred,v,stir,[morph(stir,ed(_))]).

lex(studying,v,study,[morph(study,ing)]).
lex(studies,v,study,[morph(study,s)]).
lex(studied,v,study,[morph(study,ed(_))]).

lex(telling,v,tell,[morph(tell,ing)]).
lex(tells,v,tell,[morph(tell,s)]).
lex(told,v,tell,[morph(tell,ed(_))]).

lex(throwing,v,throw,[morph(throw,ing)]).
lex(throws,v,throw,[morph(throw,s)]).
lex(threw,v,throw,[morph(throw,ed(_))]).
lex(thrown,v,throw,[morph(throw,ed(_))]).

lex(tossing,v,toss,[morph(toss,ing)]).
lex(tosses,v,toss,[morph(toss,s)]).
lex(tossed,v,toss,[morph(toss,ed(_))]).

lex(trying,v,try,[morph(try,ing)]).
lex(tries,v,try,[morph(try,s)]).
lex(tried,v,try,[morph(try,ed(_))]).

lex(thinking,v,think,[morph(think,ing)]).
lex(thinks,v,think,[morph(think,s)]).
lex(thought,v,think,[morph(think,ed(_))]).

lex(understanding,v,understand,[morph(understand,ing)]).
lex(understands,v,understand,[morph(understand,s)]).
lex(understood,v,understand,[morph(understand,ed(_))]).

lex(waking,v,wake,[morph(wake,ing)]).
lex(wakes,v,wake,[morph(wake,s)]).
lex(woke,v,wake,[morph(wake,ed(1))]).
lex(woken,v,wake,[morph(wake,ed(2))]).

lex(winning,v,win,[morph(win,ing)]).
lex(wins,v,win,[morph(win,s)]).
lex(won,v,win,[morph(win,ed(_))]).

lex(worrying,v,worry,[morph(worry,ing)]).
lex(worries,v,win,[morph(worry,s)]).
lex(worried,v,worry,[morph(worry,ed(_))]).

lex(writing,v,write,[morph(write,ing)]).
lex(writes,v,write,[morph(write,s)]).
lex(wrote,v,write,[morph(write,ed(1))]).
lex(written,v,write,[morph(write,ed(2))]).

% CONTRACTIONS
% 1st parameter is class

contraction([],'''d',[would]).
contraction([],'''ve',[have]).
contraction([],cannot,[can,not]).

contraction([],can,'''t',[can,neg]).
contraction([],X+n,'''t',[X=morph(_,_),neg]).

% morphological case spellout

no spellout_2ndline(_,_).
no spellout_3rdline(_,_).

% MISCELLANEOUS

nounFeatures(Base,F) :-	lex(Base,n,F1),	pick1(agr(_),F1,F).

verbFeatures(Base,F) :-
	lex(Base,v,F1),
	pick1(morph(Base,_),F1,F).

verbToNounFeatures(Base,F) :-
	lex(Base,v,F1),
	pick1(morph(Base,_),F1,F).
%	pickNF1(ecm(_),F2,F).	e.g. belief still needs to properly govern ...

%% MAPS MORPHOLOGY INTO SYNTACTIC FEATURES
%%	Verb morphology and Agreement
%%
%%	Form	Tense		AGR
%%	base	infinitival
%%	base	past(-)		agr(not 3,sg)
%%	-s	past(-)		agr(3,sg)
%%	-ed(1)	past(+)		agr(_)
%%	-ing	prog, infinitival
%%	-ed(2)	perf, passive
%%	am	past(-)		agr(1,sg)
%%	are	past(-)		agr(not [1,3],sg)
%%	was	past(+)		agr([1,3],sg)
%%	were	past(+)		agr(not 1,3,sg)

% non-deterministic
vMorphToFs(_,def(F),[F,agr(_)]) :-		% defective: modal auxiliaries
	!.
vMorphToFs(_,[],[]).				% infinitival form
vMorphToFs(Base,Form,Features) :-
	\+ irregular(Base,Form),
	tns(Form,F1),
	agr(Form,F2),
	append(F1,F2,Features).

% base form is irregular: (regular [] -> past(-) not 3sg)
irregular(Base,[]) :- irregular(Base).

% verb form <-> AGR feature
agr([],[agr(not([3,[sg,m],[m,f,n]]))]).
agr(s,[agr([3,[sg,m],[m,f,n]])]).
agr(ed(1),[agr(_)]).
agr(ing,[]).
agr(ed(2),[]).
agr(am,[agr([1,sg,[m,f,n]])]).
agr(are,[agr(not([[1,3],[sg,m],[m,f,n]]))]).
agr(was,[agr([[1,3],[sg,m],[m,f,n]])]).
agr(were,[agr(not([[1,3],[sg,m],[m,f,n]]))]).

% verb form <-> Tense feature
tns([],[past(-)]).
tns(s,[past(-)]).
tns(ed(1),[past(+)]).
tns(ing,[]).
tns(ed(2),[]).
tns(am,[past(-)]).
tns(are,[past(-)]).
tns(was,[past(+)]).
tns(were,[past(+)]).

%%% PREDICATES FOR INDIVIDUAL LEXICAL ITEMS

inf(V,ing) :- V has_feature morph(_,ing).

% Head movement and negation

negFromV(Neg,V) :-
	V has_feature neg,
	lexicon(not,neg,L),
	mkFs([index(_)|L],Fs),
	cat(Neg,neg),
	Neg has_features Fs,
	Neg has_pnfeatures 0,
	containsWord(Neg,'n''t').


noMax(X) :- cat(X,C), \+ max(C).

overt(X) :- \+ ec(X).

%% Choose 'it' to be a non-argument if it is in a non-trivial chain
%% o/w choose pronominal 'it'
%%
%% Q. How to derive this fact automatically?

chooseIt(R,V,OL) :-
	containsF1(OL,chain(_,_,_,_))
	-> notAssigned(R),
	   V = '+',
	   containsF1(OL,noCoindex)
	;  V = '-',
	   containsF1(OL,a(_)).

% [CP Op[i] [C' ..t[i].. ]]
% Assume t[i] O-marked theme

inheritRole(CP,Role) :-
	cat(CP,c2),
	Op specifier_of CP,
	emptyOperator(Op)
	-> Role = [theme]
	;  Role = [].
