%%% WARNING: Do not edit this file, 
%%%	     it is automatically generated at load time!

:- style_check(-discontiguous).
%%% SWI-Prolog

%%% DEFINES X-BAR THEORY AND S-STRUCTURE RULES
%%%
%%% (c) 1991, 1992, 1993, 1994  Sandiway Fong, NEC Research Institute, Inc.
%%%

%%% EXPORT
%%% X-BAR CATEGORIES AND RELATIONS
%%%	head(C)			head projection
%%%	bar(C)			intermediate projection
%%%	max(C)			maximal projection
%%%	lexicalCat(C)		lexical categories
%%%	proj(C1,C2)		C2 is the immediate projection of C1
%%%
%%%	spec(C1,SpecC)
%%%	overtSpec(C1,SpecC)
%%%	nullSpec(C1)
%%%	compl(C,ComplementC)
%%%
%%% S-STRUCTURE GRAMMAR RULES
%%%	rule LHS -> RHS
%%%	adjunction rule LHS -> RHS
%%%	Side add_goals [G1,..,Gn]
%%%	Side app_goals [G1,..,Gn]
%%%
%%% IMPORT
%%% PARAMETERS
%%%	specInitial/specFinal				parameters(Language)
%%%	headInitial/headFinal
%%%	agr(strong/weak)
%%%	negationMoves
%%%	(operators)					opDecls

:- multifile create_index/4.

%% CATEGORY LABELS

create_index(head,1,[1],unique).
create_index(max,1,[1],unique).

head(n). head(v). head(a). head(p). head(i). head(c). head(neg). 

bar(n1). bar(v1). bar(a1). bar(p1). bar(i1). bar(c1). bar(neg1).
         bar(v2).

max(np). max(vp). max(ap). max(pp). max(i2). max(c2). max(negp). 

lexicalCat(n). 	lexicalCat(v). 	lexicalCat(a). 	lexicalCat(p). lexicalCat(neg).

top(c2).

%% BASIC RELATIONS

%% for category labels X & Y, proj(X,Y) holds if Y is the
%% immediate projection of X.

create_index(proj,2,[1,2],unique).
create_index(head,2,[1,2],unique).

proj(n,n1). 	proj(n1,np).
proj(v,v1). 	proj(v1,v2). 	proj(v2,vp).
proj(a,a1). 	proj(a1,ap).
proj(p,p1). 	proj(p1,pp).
proj(c,c1). 	proj(c1,c2).
proj(i,i1). 	proj(i1,i2).
proj(neg,neg1). proj(neg1,negp).

%% head(X,Y) holds if Y is the head of X.
%% NB. Reflexive relation.

head(n,n). 	head(n1,n). 	head(np,n).
head(v,v). 	head(v1,v). 	head(v2,v). 	head(vp,v).
head(a,a). 	head(a1,a). 	head(ap,a).
head(p,p). 	head(p1,p). 	head(pp,p).     
head(c,c). 	head(c1,c). 	head(c2,c).
head(i,i). 	head(i1,i). 	head(i2,i).
head(neg,neg).	head(neg1,neg).	head(negp,neg).

%% spec(X,Y) holds if Y can be the specifier for X (single-bar).
%% NB.	1. Option for no specifier indicated by Y=[].
%%      2. X is the category label for the sister to Y.

spec(n1,det).	spec(n1,np). 	spec(n1,[]).
spec(i1,np).
spec(c1,[]).

overtSpec(X1,Y) :- spec(X1,Y), Y \== [].
nullSpec(X1) :- spec(X1,[]) ; \+ spec(X1,_).

%% compl(X,Y) holds if Y can be the complement of X.
%% NB.	1. No complement option not available here.
%%	2. Additional definitions from lexicon (theta-grids,subcat)
%%	3. X is the category label for the sister to Y

compl(i,vp).	compl(i,negp). compl(neg,vp). compl(c,i2).

%% X-BAR RULES

rule XP -> [XB|spec(XB)] ordered specFinal st max(XP), proj(XB,XP).

rule spec(XB) -> [Y] st overtSpec(XB,Y).
rule spec(XB) -> [] st nullSpec(XB).

rule XB2 -> [XB1|icompl(XB1)] ordered headInitial(X0)
			      st bar(XB2), proj(XB1,XB2), bar(XB1),
			         head(XB2,X0), head(X0).

rule icompl(XB) -> [] st lexicalProperty(XB,subcat(_,_),_).
rule icompl(XB) -> [] st lexicalProperty(XB,grid(_,Roles),no2ndRole(Roles),_).
rule icompl(XB) -> [Y] st lexicalProperty(XB,grid(_,Roles),csr2nd(Roles,Y),Y).

rule XB -> [X|compl(X)] ordered headInitial(X)
			st bar(XB), proj(X,XB), head(X).

rule compl(X) -> [] st lexicalProperty(X,grid(_,Roles),no1stRole(Roles),_).
rule compl(X) -> [Y] st compl(X,Y).
rule compl(X) -> [Y] st lexicalProperty(X,grid(_,Roles),csr1st(Roles,Y),Y).
rule compl(X) -> [Y] st lexicalProperty(X,subcat(Y$_,_),Y).

%% NON-X-BAR RULES

% Empty categories

rule np with Fs -> [] st ecNPFeatures(Fs).
rule c with Fs -> [] st emptyCompFeatures(Fs).	  % language-specific

%% HEAD MOVEMENT
%% NB. requires rule for empty C for adjunction in periphery

rule v(V) moves_to i provided agr(strong), finite(V).
rule v(V) moves_to i provided agr(weak), V has_feature aux.

rule v(V) moves_to i moves_to c provided agr(strong), finite(V).
rule v(V) moves_to i moves_to c provided 
	agr(weak), V has_feature aux, finite(V).

rule i(I) moves_to v(V) provided agr(weak), \+ V has_feature aux,
	post_cond addFeature(noECP(_),I).
rule i(I) moves_to v(V) provided agr(strong), \+ finite(V),
	post_cond addFeature(noECP(_),I).

rule v doesnt_move provided v$vp subcat_by v.
rule v(V) moves_through neg provided_iff negationMoves, V has_feature neg.

rule i(I) derived_from v(V) provided recoverIfromV(I,V).
rule neg(Neg) derived_from v(V) provided negFromV(Neg,V).

% Coping with antecedent government of head traces
rule head_adjoined _ add_feature transparent(ecp).

% Special categories

rule relClNP -> [overtNP] st true.
rule overtNP -> [np(NP)] st \+ ec(NP).
rule cpAdjAP -> [ap(AP)] st AP has_feature allowExt(reason).

%% ADJUNCTION

% Adjunction to head

adjunction rule n -> [a,n] st lexicalProperty(a,grid([_],_)).
adjunction rule a -> [adv,a] st lexicalProperty(adv,degree).
adjunction rule v -> [v,adv] ordered headInitial(v) 
				st lexicalProperty(adv,degree).

adjunction rule i -> [cl,i] st lexicalProperty(cl,morphC(nom)).
adjunction rule i -> [cl,i] st lexicalProperty(cl,polarity(negative)).

% Adjunction to max

adjunction rule vp -> [vp,pp] ordered headInitial(v).
adjunction rule vp -> [vp,adv] st lexicalProperty(adv,adjoin(right)).
adjunction rule vp -> [adv,vp] st lexicalProperty(adv,adjoin(left)).

adjunction rule np -> [relClNP,c2] ordered headInitial(n).
% new
adjunction rule np -> [overtNP, pp] ordered headInitial(n).

adjunction rule ap -> [cpAdjAP,c2].

% Bracketing (local rules respect bracketing)

bracket c2.
bracket i2 idominated_by v1.
bracket i2 idominated_by n1.
bracket i2 idominated_by p1.

%% MODIFICATION RULES

%% Define subjects to have feature apos (A-position)

rhs [np(NP),i1] ordered specInitial app_goals [aPos(NP)].
rhs [np(NP),n1(N1)] ordered specInitial app_goals [aPos(NP),npSpecNP(NP,N1)].

rhs anywhere i1(X) add_goals [matrixIPFeature(X)].

left_bracket c2 add_goals [unboundedLookahead(input(i),input(o))].
left_bracket i2 idominated_by v1 
	add_goals [unboundedLookahead(input(i),input(o))].
left_bracket i2 idominated_by n1 
	add_goals [unboundedLookahead(input(i),input(o))].
left_bracket i2 idominated_by p1 
	add_goals [unboundedLookahead(input(i),input(o))].

%%% SUPPORTING DEFINITIONS

%% allow [SPEC,NP] 
%% 1a. N has a non-empty 0-grid, or
%% 1b. SPEC is a nonargument
%% And:
%% 2. Its complement (if one exists) is not a CP.
%% 3. Anti-coindexation holds between [SPEC,NP] and NP

npSpecNP(NP,N1) :-
	( nonEmptyGrid(N1) ; NP has_feature nonarg(+)),
	!,					  % red
	\+ cat(Compl,c2) if Compl complement_of N1,
	antiCoindex(NP,N1).

antiCoindex(X,Y) :-
	index(X,I),
	index(Y,J),
	addFeature(neq(I,J),Y),
	addFeature(neq(I,J),X).

%% Feature [matrix] is added to all matrix IPs
matrixIPFeature(X) :- addFeature(matrix,X) if isMatrixLevel.

%% INFL and V

finite(V) :- \+ V has_feature inf(_).

recoverIfromV(I,V) :-
	inflFeatures(V,Fs),
	mkEC(i,Fs,I).
	
inflFeatures(V,Fs) :- infinitival(V,Fs).
inflFeatures(V,Fs) :- tnsAGRFeatures(V,Fs).
	
%% either
%% 1. inf([]) from an infinitival marker, or
%% 2. language-specific
%% nb. only for non-simple verbs

infinitival(V,Fs) :-
	( V has_feature inf(X) 
	; inf(V,X)),				  % language-specific
	!,
	mkFs([index(_),inf(X)],Fs).

%% only for tensed forms

tnsAGRFeatures(V,Fs) :-
	V has_feature morph(Base,Form),
	\+ V has_feature inf(_),
	vMorphToFs(Base,Form,[TnsAGR|Fs1]),
	mkFs([index(_),TnsAGR|Fs1],Fs).

%% Empty NP
%% 1. BT relevant features (+/-A +/-P) will be assigned by functionalDet
%% 2. AGR,Theta and (possibly) Case slots will be unified by resolveTraces
%% 3. ec(_) is used by lexical restrictions

ecNPFeatures(Fs) :- mkFs([agr(_),case(_),theta(_),a(_),p(_),ec(_)],Fs).



% temp: clashes with glrRT.pl

% returns spec of IP for clauses
subject_of(Subj,IP) :-
	cat(IP,i2),
	Subj specifier_of IP.
subject_of(Subj,CP) :-
	cat(CP,c2),
	IP complement_of CP,
	Subj specifier_of IP.
%%% SWI-Prolog

%%% PERIPHERY 
%%%
%%% (c) 1991, 1992, 1993  Sandiway Fong, NEC Research Institute, Inc.
%%%
%%% Language-particular operations + kludgey stuff

%%% S-STRUCTURE GRAMMAR ADDITIONS

% Have to be a bit picky in what we allow in [Spec,CP] for English
spec(c1,exnp). 	
spec(c1,whadv).	

rule empty c with Fs st mkFs([wh(+)],Fs).		  % for head movement

rule exnp -> [np(NP)] st \+ ec(NP) if isMatrixLevel.
rule neg -> [neg] st blockILowering(es(i)).
rule whadv -> [adv(Adv)] st specCPWhAdv(Adv,es(i),es(o)).

rule adv -> trace.

rule head_adjoined v to neg adjoins_to_the left.  % in head movement

%%% GRAMMAR RULE RESTRICTIONS

% Don't allow Q in matrix Comp when an Aux Verb can be used.
rhs [whadv(X),c1(Y)] add_goals [matrixQException(X,Y)].
rhs [exnp(X),c1(Y)] add_goals [matrixQException(X,Y)].

% Reduce non-determinism for adjunction
rhs [vsubcatvp,vp(VP)] add_goals [\+ adjoinedMax(VP)].

% Relativized subjects with no overt relative pronoun are not allowed
% *[NP [NP the man][c2 Op [c1 [c] [i2 NP-e ...]]]]
% *[NP [NP proper noun][c2 Op [c1 [c] [i2 ...]]]]
rhs [relClNP(NP),c2(CP)] add_goals [blockECSubjRelClause(CP),blockProperNounEmptyComp(NP,CP)].

% Check for that obligatory adjuncts are present
rhs [i,vp(X)] add_goals [vpRequiresExt(X)].
rhs [neg,vp(X)] add_goals [vpRequiresExt(X)].

%%% SUPPORT FOR DETERMINER/N1 INTERACTION

%% Determiner and N1 interaction

rhs [n1(N1)]		add_goals [noDet(N1)].
rhs [det(Det),n1(N1)] 	add_goals [detAgreement(Det,N1)].

% Inherit [wh(_),op(+/-)] features from spec instead of head

rhs [det,n1] 		add_inherit plus(2,[1,[wh(_),op(_)]]).

%% no determiner option possible for: 
%%	1. non-common, or
%%	2. non-count, or
%%	3. plural count nouns only.

noDet(N1) :- \+ N1 has_feature count(_).
noDet(N1) :- N1 has_feature count(-).
noDet(N1) :- 
	N1 has_feature count(+),
	intersectAGR(N1,[[],pl,[]]).

detAgreement(Det,N1) :- 
	Det has_feature count(C),
	N1 has_feature count(C),
	agreeAGR(Det,N1),
	vowelMatch(Det,N1).

% a(n)
vowelMatch(Det,N1) :-
	(Type == '+' iff beginsWithVowel(N1))
	if Det has_feature vow(Type).

% left edge must have feature vow(+)
beginsWithVowel(X) :-
	X has_constituents [Left|_]
        -> beginsWithVowel(Left)
        ;  X has_feature vow(+).

%%% CASE THEORY

% compatibleCase(AssignedCase,MorphologicallyRealizedCase)

compatibleCase(X,X).
compatibleCase(gen,acc).   % for 'proud of him'
compatibleCase(obq,acc).   % for 'to him'
compatibleCase(opt(_,X),X).	% optional Case marking

% Case Transmission
no caseTransmission(_,_,_).

% Genitive Case realization (of/'s)
realizedAsMarker(gen).

caseRealizationMode(NP,Mode) :-
	NP has_feature compl
	-> Mode = case				  % of him
	;  Mode = caseMorphC.			  % John's, his

%%% EMPTY COMP

% To satisfy the WhInSyntax filter, 
%	matrix [C] is freely  [+/-Wh], e.g. who left, john left

emptyCompFeatures(Fs) :- mkFs([wh(_)],Fs).

%%% Move-Alpha (D-structure to S-structure)

moves(CF,C) :- cat(CF,C), member(C,[np,adv]).

%%% MATRIX COMP AND WH-ELEMENTS

% Don't allow Q when there exists a [wh(+),aux] element that can be raised.
% Use this to temporarily block overgeneration in cases like:
%	who [c] was arrested
%	who [c c [i i [v was]]] t arrested

matrixQException(Spec,C1) :-  
	\+ (Spec has_feature wh(+),whCAux(C1)) if isMatrixLevel.

q(C) :- ec(C), C has_feature wh(+).

whCAux(C1) :-
	C0 head_of C1,
	q(C0),
	IP complement_of C1,
	I0 head_of IP,
	adjoined(I0,V),
	V has_feature aux.

%%% RELATIVE CLAUSE RESTRICTIONS

% block subject to empty operator extraction, e.g. *the man Op t saw me
% where there is nothing in Comp (cf. the man that saw me)

blockECSubjRelClause(CP) :- \+ emptySpecHeadSubj(CP).

% [c2 Op [c1 ... [i2 NP-e ... ]]]
emptySpecHeadSubj(CP) :-
	cat(CP,c2),
	Spec specifier_of CP, 	ec(Spec),
	Subj subject_of CP,	ec(Subj),
	Head head_of CP,	ec(Head).

blockProperNounEmptyComp(NP,CP) :- \+ (properNounNP(NP), emptySpecHeadComp(CP)).

properNounNP(NP) :- cat(NP,np), \+ NP has_feature count(_).

emptySpecHeadComp(CP) :-
    cat(CP,c2),
    Spec specifier_of CP, ec(Spec),
    Head head_of CP, ec(Head).

%% Chain Formation conditions

chainLinkConditions(New,Head,L,UpPath,DownPath) :-
	cat(New,C),
	linkCondition(C,New,Head,L,UpPath,DownPath).

% 1. antecedent c-commanded traces
% 2. base position iff adjunct position

linkCondition(adv,_,Trace,L,_,[]) :-
	Trace has_feature adjunct if L == [].

linkCondition(np,Head,_,_,UpPath,DownPath) :-
	\+ vacuousTopicalization(Head,UpPath,DownPath).

% Example: blocks [CP John [IP t sleeps]] given A-to-A-bar Case transmission

vacuousTopicalization(Head,[IP,C1],[]) :- 
	cat(IP,i2),
	cat(C1,c1),
	cat(Head,np), \+ ec(Head), \+ Head has_feature wh(+).

%%% MISCELLANEOUS

%% Negation blocks I-lowering to V

blockILowering(ES) :- \+ popPTr(i,_,ES,_).	  % machine code

% Adv in [Spec,CP] st.
% Intermediate trace 	if empty category
% [Wh]Adv  		otherwise
% 
% NB. Assumes left to right

specCPWhAdv(Adv,ES,ESp) :-
	ec(Adv)
	-> make Adv have_feature ec(trace),
	   predictTrace(Adv,ES,ESp)
	;  Adv has_feature wh(+), 
	   predictTrace(Adv,ES,ESp).

no shiftRequest(_,_).

% NB: should allow for [VP [V2 [V1 [V V Adv]]]] collapsing to [VP V Adv]
adjoinedMax(X) :- adjoined(X,_,Y), cat(Y,C), max(C).

% hack for demo only

% Fre
notPro(A,P) :- \+ (A == '-', P == '+' ).

% Ger
nomOnlyWithPro(Slot,A,P) :-
	A == '-',
	P == '+'
	-> assigned(Slot),
	   Slot == nom
	;  true.

:- style_check(+discontiguous).
